class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QSql():
    """"""
    # Enum QSql.NumericalPrecisionPolicy
    LowPrecisionInt32 = 0
    LowPrecisionInt64 = 0
    LowPrecisionDouble = 0
    HighPrecision = 0

    # Enum QSql.TableType
    Tables = 0
    SystemTables = 0
    Views = 0
    AllTables = 0

    # Enum QSql.ParamTypeFlag
    In = 0
    Out = 0
    InOut = 0
    Binary = 0

    # Enum QSql.Location
    BeforeFirstRow = 0
    AfterLastRow = 0

    class ParamType():
        """"""
        def __init__(self):
            '''QSql.ParamType QSql.ParamType.__init__()'''
            return QSql.ParamType()
        def __init__(self):
            '''int QSql.ParamType.__init__()'''
            return int()
        def __init__(self):
            '''void QSql.ParamType.__init__()'''
        def __bool__(self):
            '''int QSql.ParamType.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QSql.ParamType.__ne__(QSql.ParamType f)'''
            return bool()
        def __eq__(self, f):
            '''bool QSql.ParamType.__eq__(QSql.ParamType f)'''
            return bool()
        def __invert__(self):
            '''QSql.ParamType QSql.ParamType.__invert__()'''
            return QSql.ParamType()
        def __and__(self, mask):
            '''QSql.ParamType QSql.ParamType.__and__(int mask)'''
            return QSql.ParamType()
        def __xor__(self, f):
            '''QSql.ParamType QSql.ParamType.__xor__(QSql.ParamType f)'''
            return QSql.ParamType()
        def __xor__(self, f):
            '''QSql.ParamType QSql.ParamType.__xor__(int f)'''
            return QSql.ParamType()
        def __or__(self, f):
            '''QSql.ParamType QSql.ParamType.__or__(QSql.ParamType f)'''
            return QSql.ParamType()
        def __or__(self, f):
            '''QSql.ParamType QSql.ParamType.__or__(int f)'''
            return QSql.ParamType()
        def __int__(self):
            '''int QSql.ParamType.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QSql.ParamType QSql.ParamType.__ixor__(QSql.ParamType f)'''
            return QSql.ParamType()
        def __ior__(self, f):
            '''QSql.ParamType QSql.ParamType.__ior__(QSql.ParamType f)'''
            return QSql.ParamType()
        def __iand__(self, mask):
            '''QSql.ParamType QSql.ParamType.__iand__(int mask)'''
            return QSql.ParamType()


class QSqlDriverCreatorBase():
    """"""
    def __init__(self):
        '''void QSqlDriverCreatorBase.__init__()'''
    def __init__(self):
        '''QSqlDriverCreatorBase QSqlDriverCreatorBase.__init__()'''
        return QSqlDriverCreatorBase()
    def createObject(self):
        '''abstract QSqlDriver QSqlDriverCreatorBase.createObject()'''
        return QSqlDriver()


class QSqlDatabase():
    """"""
    def __init__(self):
        '''void QSqlDatabase.__init__()'''
    def __init__(self, other):
        '''void QSqlDatabase.__init__(QSqlDatabase other)'''
    def __init__(self, type):
        '''void QSqlDatabase.__init__(str type)'''
    def __init__(self, driver):
        '''void QSqlDatabase.__init__(QSqlDriver driver)'''
    def numericalPrecisionPolicy(self):
        '''QSql.NumericalPrecisionPolicy QSqlDatabase.numericalPrecisionPolicy()'''
        return QSql.NumericalPrecisionPolicy()
    def setNumericalPrecisionPolicy(self, precisionPolicy):
        '''void QSqlDatabase.setNumericalPrecisionPolicy(QSql.NumericalPrecisionPolicy precisionPolicy)'''
    def isDriverAvailable(self, name):
        '''static bool QSqlDatabase.isDriverAvailable(str name)'''
        return bool()
    def registerSqlDriver(self, name, creator):
        '''static void QSqlDatabase.registerSqlDriver(str name, QSqlDriverCreatorBase creator)'''
    def connectionNames(self):
        '''static list-of-str QSqlDatabase.connectionNames()'''
        return [str()]
    def drivers(self):
        '''static list-of-str QSqlDatabase.drivers()'''
        return [str()]
    def contains(self, connectionName = None):
        '''static bool QSqlDatabase.contains(str connectionName = QLatin1String(QSqlDatabase.defaultConnection))'''
        return bool()
    def removeDatabase(self, connectionName):
        '''static void QSqlDatabase.removeDatabase(str connectionName)'''
    def database(self, connectionName = None, open = True):
        '''static QSqlDatabase QSqlDatabase.database(str connectionName = QLatin1String(QSqlDatabase.defaultConnection), bool open = True)'''
        return QSqlDatabase()
    def cloneDatabase(self, other, connectionName):
        '''static QSqlDatabase QSqlDatabase.cloneDatabase(QSqlDatabase other, str connectionName)'''
        return QSqlDatabase()
    def addDatabase(self, type, connectionName = None):
        '''static QSqlDatabase QSqlDatabase.addDatabase(str type, str connectionName = QLatin1String(QSqlDatabase.defaultConnection))'''
        return QSqlDatabase()
    def addDatabase(self, driver, connectionName = None):
        '''static QSqlDatabase QSqlDatabase.addDatabase(QSqlDriver driver, str connectionName = QLatin1String(QSqlDatabase.defaultConnection))'''
        return QSqlDatabase()
    def driver(self):
        '''QSqlDriver QSqlDatabase.driver()'''
        return QSqlDriver()
    def connectionName(self):
        '''str QSqlDatabase.connectionName()'''
        return str()
    def connectOptions(self):
        '''str QSqlDatabase.connectOptions()'''
        return str()
    def port(self):
        '''int QSqlDatabase.port()'''
        return int()
    def driverName(self):
        '''str QSqlDatabase.driverName()'''
        return str()
    def hostName(self):
        '''str QSqlDatabase.hostName()'''
        return str()
    def password(self):
        '''str QSqlDatabase.password()'''
        return str()
    def userName(self):
        '''str QSqlDatabase.userName()'''
        return str()
    def databaseName(self):
        '''str QSqlDatabase.databaseName()'''
        return str()
    def setConnectOptions(self, options = None):
        '''void QSqlDatabase.setConnectOptions(str options = '')'''
    def setPort(self, p):
        '''void QSqlDatabase.setPort(int p)'''
    def setHostName(self, host):
        '''void QSqlDatabase.setHostName(str host)'''
    def setPassword(self, password):
        '''void QSqlDatabase.setPassword(str password)'''
    def setUserName(self, name):
        '''void QSqlDatabase.setUserName(str name)'''
    def setDatabaseName(self, name):
        '''void QSqlDatabase.setDatabaseName(str name)'''
    def rollback(self):
        '''bool QSqlDatabase.rollback()'''
        return bool()
    def commit(self):
        '''bool QSqlDatabase.commit()'''
        return bool()
    def transaction(self):
        '''bool QSqlDatabase.transaction()'''
        return bool()
    def isValid(self):
        '''bool QSqlDatabase.isValid()'''
        return bool()
    def lastError(self):
        '''QSqlError QSqlDatabase.lastError()'''
        return QSqlError()
    def exec_(self, query = None):
        '''QSqlQuery QSqlDatabase.exec_(str query = '')'''
        return QSqlQuery()
    def record(self, tablename):
        '''QSqlRecord QSqlDatabase.record(str tablename)'''
        return QSqlRecord()
    def primaryIndex(self, tablename):
        '''QSqlIndex QSqlDatabase.primaryIndex(str tablename)'''
        return QSqlIndex()
    def tables(self, type = None):
        '''list-of-str QSqlDatabase.tables(QSql.TableType type = QSql.Tables)'''
        return [str()]
    def isOpenError(self):
        '''bool QSqlDatabase.isOpenError()'''
        return bool()
    def isOpen(self):
        '''bool QSqlDatabase.isOpen()'''
        return bool()
    def close(self):
        '''void QSqlDatabase.close()'''
    def open(self):
        '''bool QSqlDatabase.open()'''
        return bool()
    def open(self, user, password):
        '''bool QSqlDatabase.open(str user, str password)'''
        return bool()


class QSqlDriver(QObject):
    """"""
    # Enum QSqlDriver.DbmsType
    UnknownDbms = 0
    MSSqlServer = 0
    MySqlServer = 0
    PostgreSQL = 0
    Oracle = 0
    Sybase = 0
    SQLite = 0
    Interbase = 0
    DB2 = 0

    # Enum QSqlDriver.NotificationSource
    UnknownSource = 0
    SelfSource = 0
    OtherSource = 0

    # Enum QSqlDriver.IdentifierType
    FieldName = 0
    TableName = 0

    # Enum QSqlDriver.StatementType
    WhereStatement = 0
    SelectStatement = 0
    UpdateStatement = 0
    InsertStatement = 0
    DeleteStatement = 0

    # Enum QSqlDriver.DriverFeature
    Transactions = 0
    QuerySize = 0
    BLOB = 0
    Unicode = 0
    PreparedQueries = 0
    NamedPlaceholders = 0
    PositionalPlaceholders = 0
    LastInsertId = 0
    BatchOperations = 0
    SimpleLocking = 0
    LowPrecisionNumbers = 0
    EventNotifications = 0
    FinishQuery = 0
    MultipleResultSets = 0

    def __init__(self, parent = None):
        '''void QSqlDriver.__init__(QObject parent = None)'''
    def dbmsType(self):
        '''QSqlDriver.DbmsType QSqlDriver.dbmsType()'''
        return QSqlDriver.DbmsType()
    def numericalPrecisionPolicy(self):
        '''QSql.NumericalPrecisionPolicy QSqlDriver.numericalPrecisionPolicy()'''
        return QSql.NumericalPrecisionPolicy()
    def setNumericalPrecisionPolicy(self, precisionPolicy):
        '''void QSqlDriver.setNumericalPrecisionPolicy(QSql.NumericalPrecisionPolicy precisionPolicy)'''
    def stripDelimiters(self, identifier, type):
        '''str QSqlDriver.stripDelimiters(str identifier, QSqlDriver.IdentifierType type)'''
        return str()
    def isIdentifierEscaped(self, identifier, type):
        '''bool QSqlDriver.isIdentifierEscaped(str identifier, QSqlDriver.IdentifierType type)'''
        return bool()
    notification = pyqtSignal() # void notification(const QStringamp;) - signal
    notification = pyqtSignal() # void notification(const QStringamp;,QSqlDriver::NotificationSource,const QVariantamp;) - signal
    def subscribedToNotifications(self):
        '''list-of-str QSqlDriver.subscribedToNotifications()'''
        return [str()]
    def unsubscribeFromNotification(self, name):
        '''bool QSqlDriver.unsubscribeFromNotification(str name)'''
        return bool()
    def subscribeToNotification(self, name):
        '''bool QSqlDriver.subscribeToNotification(str name)'''
        return bool()
    def setLastError(self, e):
        '''void QSqlDriver.setLastError(QSqlError e)'''
    def setOpenError(self, e):
        '''void QSqlDriver.setOpenError(bool e)'''
    def setOpen(self, o):
        '''void QSqlDriver.setOpen(bool o)'''
    def open(self, db, user = None, password = None, host = None, port = None, options = None):
        '''abstract bool QSqlDriver.open(str db, str user = '', str password = '', str host = '', int port = -1, str options = '')'''
        return bool()
    def createResult(self):
        '''abstract QSqlResult QSqlDriver.createResult()'''
        return QSqlResult()
    def close(self):
        '''abstract void QSqlDriver.close()'''
    def hasFeature(self, f):
        '''abstract bool QSqlDriver.hasFeature(QSqlDriver.DriverFeature f)'''
        return bool()
    def handle(self):
        '''QVariant QSqlDriver.handle()'''
        return QVariant()
    def lastError(self):
        '''QSqlError QSqlDriver.lastError()'''
        return QSqlError()
    def sqlStatement(self, type, tableName, rec, preparedStatement):
        '''str QSqlDriver.sqlStatement(QSqlDriver.StatementType type, str tableName, QSqlRecord rec, bool preparedStatement)'''
        return str()
    def escapeIdentifier(self, identifier, type):
        '''str QSqlDriver.escapeIdentifier(str identifier, QSqlDriver.IdentifierType type)'''
        return str()
    def formatValue(self, field, trimStrings = False):
        '''str QSqlDriver.formatValue(QSqlField field, bool trimStrings = False)'''
        return str()
    def record(self, tableName):
        '''QSqlRecord QSqlDriver.record(str tableName)'''
        return QSqlRecord()
    def primaryIndex(self, tableName):
        '''QSqlIndex QSqlDriver.primaryIndex(str tableName)'''
        return QSqlIndex()
    def tables(self, tableType):
        '''list-of-str QSqlDriver.tables(QSql.TableType tableType)'''
        return [str()]
    def rollbackTransaction(self):
        '''bool QSqlDriver.rollbackTransaction()'''
        return bool()
    def commitTransaction(self):
        '''bool QSqlDriver.commitTransaction()'''
        return bool()
    def beginTransaction(self):
        '''bool QSqlDriver.beginTransaction()'''
        return bool()
    def isOpenError(self):
        '''bool QSqlDriver.isOpenError()'''
        return bool()
    def isOpen(self):
        '''bool QSqlDriver.isOpen()'''
        return bool()


class QSqlError():
    """"""
    # Enum QSqlError.ErrorType
    NoError = 0
    ConnectionError = 0
    StatementError = 0
    TransactionError = 0
    UnknownError = 0

    def __init__(self, driverText = None, databaseText = None, type = None, errorCode = str()):
        '''void QSqlError.__init__(str driverText = '', str databaseText = '', QSqlError.ErrorType type = QSqlError.NoError, str errorCode = str())'''
    def __init__(self, driverText, databaseText, type, number):
        '''void QSqlError.__init__(str driverText, str databaseText, QSqlError.ErrorType type, int number)'''
    def __init__(self, other):
        '''void QSqlError.__init__(QSqlError other)'''
    def nativeErrorCode(self):
        '''str QSqlError.nativeErrorCode()'''
        return str()
    def __ne__(self, other):
        '''bool QSqlError.__ne__(QSqlError other)'''
        return bool()
    def __eq__(self, other):
        '''bool QSqlError.__eq__(QSqlError other)'''
        return bool()
    def isValid(self):
        '''bool QSqlError.isValid()'''
        return bool()
    def text(self):
        '''str QSqlError.text()'''
        return str()
    def setNumber(self, number):
        '''void QSqlError.setNumber(int number)'''
    def number(self):
        '''int QSqlError.number()'''
        return int()
    def setType(self, type):
        '''void QSqlError.setType(QSqlError.ErrorType type)'''
    def type(self):
        '''QSqlError.ErrorType QSqlError.type()'''
        return QSqlError.ErrorType()
    def setDatabaseText(self, databaseText):
        '''void QSqlError.setDatabaseText(str databaseText)'''
    def databaseText(self):
        '''str QSqlError.databaseText()'''
        return str()
    def setDriverText(self, driverText):
        '''void QSqlError.setDriverText(str driverText)'''
    def driverText(self):
        '''str QSqlError.driverText()'''
        return str()


class QSqlField():
    """"""
    # Enum QSqlField.RequiredStatus
    Unknown = 0
    Optional = 0
    Required = 0

    def __init__(self, fieldName = None, type = None):
        '''void QSqlField.__init__(str fieldName = '', QVariant.Type type = QVariant.Invalid)'''
    def __init__(self, other):
        '''void QSqlField.__init__(QSqlField other)'''
    def isValid(self):
        '''bool QSqlField.isValid()'''
        return bool()
    def isGenerated(self):
        '''bool QSqlField.isGenerated()'''
        return bool()
    def typeID(self):
        '''int QSqlField.typeID()'''
        return int()
    def defaultValue(self):
        '''QVariant QSqlField.defaultValue()'''
        return QVariant()
    def precision(self):
        '''int QSqlField.precision()'''
        return int()
    def length(self):
        '''int QSqlField.length()'''
        return int()
    def requiredStatus(self):
        '''QSqlField.RequiredStatus QSqlField.requiredStatus()'''
        return QSqlField.RequiredStatus()
    def setAutoValue(self, autoVal):
        '''void QSqlField.setAutoValue(bool autoVal)'''
    def setGenerated(self, gen):
        '''void QSqlField.setGenerated(bool gen)'''
    def setSqlType(self, type):
        '''void QSqlField.setSqlType(int type)'''
    def setDefaultValue(self, value):
        '''void QSqlField.setDefaultValue(QVariant value)'''
    def setPrecision(self, precision):
        '''void QSqlField.setPrecision(int precision)'''
    def setLength(self, fieldLength):
        '''void QSqlField.setLength(int fieldLength)'''
    def setRequired(self, required):
        '''void QSqlField.setRequired(bool required)'''
    def setRequiredStatus(self, status):
        '''void QSqlField.setRequiredStatus(QSqlField.RequiredStatus status)'''
    def setType(self, type):
        '''void QSqlField.setType(QVariant.Type type)'''
    def isAutoValue(self):
        '''bool QSqlField.isAutoValue()'''
        return bool()
    def type(self):
        '''QVariant.Type QSqlField.type()'''
        return QVariant.Type()
    def clear(self):
        '''void QSqlField.clear()'''
    def isReadOnly(self):
        '''bool QSqlField.isReadOnly()'''
        return bool()
    def setReadOnly(self, readOnly):
        '''void QSqlField.setReadOnly(bool readOnly)'''
    def isNull(self):
        '''bool QSqlField.isNull()'''
        return bool()
    def name(self):
        '''str QSqlField.name()'''
        return str()
    def setName(self, name):
        '''void QSqlField.setName(str name)'''
    def value(self):
        '''QVariant QSqlField.value()'''
        return QVariant()
    def setValue(self, value):
        '''void QSqlField.setValue(QVariant value)'''
    def __ne__(self, other):
        '''bool QSqlField.__ne__(QSqlField other)'''
        return bool()
    def __eq__(self, other):
        '''bool QSqlField.__eq__(QSqlField other)'''
        return bool()


class QSqlRecord():
    """"""
    def __init__(self):
        '''void QSqlRecord.__init__()'''
    def __init__(self, other):
        '''void QSqlRecord.__init__(QSqlRecord other)'''
    def keyValues(self, keyFields):
        '''QSqlRecord QSqlRecord.keyValues(QSqlRecord keyFields)'''
        return QSqlRecord()
    def __len__(self):
        ''' QSqlRecord.__len__()'''
        return ()
    def count(self):
        '''int QSqlRecord.count()'''
        return int()
    def clearValues(self):
        '''void QSqlRecord.clearValues()'''
    def clear(self):
        '''void QSqlRecord.clear()'''
    def contains(self, name):
        '''bool QSqlRecord.contains(str name)'''
        return bool()
    def isEmpty(self):
        '''bool QSqlRecord.isEmpty()'''
        return bool()
    def remove(self, pos):
        '''void QSqlRecord.remove(int pos)'''
    def insert(self, pos, field):
        '''void QSqlRecord.insert(int pos, QSqlField field)'''
    def replace(self, pos, field):
        '''void QSqlRecord.replace(int pos, QSqlField field)'''
    def append(self, field):
        '''void QSqlRecord.append(QSqlField field)'''
    def setGenerated(self, name, generated):
        '''void QSqlRecord.setGenerated(str name, bool generated)'''
    def setGenerated(self, i, generated):
        '''void QSqlRecord.setGenerated(int i, bool generated)'''
    def isGenerated(self, i):
        '''bool QSqlRecord.isGenerated(int i)'''
        return bool()
    def isGenerated(self, name):
        '''bool QSqlRecord.isGenerated(str name)'''
        return bool()
    def field(self, i):
        '''QSqlField QSqlRecord.field(int i)'''
        return QSqlField()
    def field(self, name):
        '''QSqlField QSqlRecord.field(str name)'''
        return QSqlField()
    def fieldName(self, i):
        '''str QSqlRecord.fieldName(int i)'''
        return str()
    def indexOf(self, name):
        '''int QSqlRecord.indexOf(str name)'''
        return int()
    def isNull(self, i):
        '''bool QSqlRecord.isNull(int i)'''
        return bool()
    def isNull(self, name):
        '''bool QSqlRecord.isNull(str name)'''
        return bool()
    def setNull(self, i):
        '''void QSqlRecord.setNull(int i)'''
    def setNull(self, name):
        '''void QSqlRecord.setNull(str name)'''
    def setValue(self, i, val):
        '''void QSqlRecord.setValue(int i, QVariant val)'''
    def setValue(self, name, val):
        '''void QSqlRecord.setValue(str name, QVariant val)'''
    def value(self, i):
        '''QVariant QSqlRecord.value(int i)'''
        return QVariant()
    def value(self, name):
        '''QVariant QSqlRecord.value(str name)'''
        return QVariant()
    def __ne__(self, other):
        '''bool QSqlRecord.__ne__(QSqlRecord other)'''
        return bool()
    def __eq__(self, other):
        '''bool QSqlRecord.__eq__(QSqlRecord other)'''
        return bool()


class QSqlIndex(QSqlRecord):
    """"""
    def __init__(self, cursorName = None, name = None):
        '''void QSqlIndex.__init__(str cursorName = '', str name = '')'''
    def __init__(self, other):
        '''void QSqlIndex.__init__(QSqlIndex other)'''
    def setDescending(self, i, desc):
        '''void QSqlIndex.setDescending(int i, bool desc)'''
    def isDescending(self, i):
        '''bool QSqlIndex.isDescending(int i)'''
        return bool()
    def append(self, field):
        '''void QSqlIndex.append(QSqlField field)'''
    def append(self, field, desc):
        '''void QSqlIndex.append(QSqlField field, bool desc)'''
    def name(self):
        '''str QSqlIndex.name()'''
        return str()
    def setName(self, name):
        '''void QSqlIndex.setName(str name)'''
    def cursorName(self):
        '''str QSqlIndex.cursorName()'''
        return str()
    def setCursorName(self, cursorName):
        '''void QSqlIndex.setCursorName(str cursorName)'''


class QSqlQuery():
    """"""
    # Enum QSqlQuery.BatchExecutionMode
    ValuesAsRows = 0
    ValuesAsColumns = 0

    def __init__(self, r):
        '''void QSqlQuery.__init__(QSqlResult r)'''
    def __init__(self, query = None, db = QSqlDatabase()):
        '''void QSqlQuery.__init__(str query = '', QSqlDatabase db = QSqlDatabase())'''
    def __init__(self, db):
        '''void QSqlQuery.__init__(QSqlDatabase db)'''
    def __init__(self, other):
        '''void QSqlQuery.__init__(QSqlQuery other)'''
    def nextResult(self):
        '''bool QSqlQuery.nextResult()'''
        return bool()
    def finish(self):
        '''void QSqlQuery.finish()'''
    def numericalPrecisionPolicy(self):
        '''QSql.NumericalPrecisionPolicy QSqlQuery.numericalPrecisionPolicy()'''
        return QSql.NumericalPrecisionPolicy()
    def setNumericalPrecisionPolicy(self, precisionPolicy):
        '''void QSqlQuery.setNumericalPrecisionPolicy(QSql.NumericalPrecisionPolicy precisionPolicy)'''
    def lastInsertId(self):
        '''QVariant QSqlQuery.lastInsertId()'''
        return QVariant()
    def executedQuery(self):
        '''str QSqlQuery.executedQuery()'''
        return str()
    def boundValues(self):
        '''dict-of-QString-QVariant QSqlQuery.boundValues()'''
        return {str():QVariant()}
    def boundValue(self, placeholder):
        '''QVariant QSqlQuery.boundValue(str placeholder)'''
        return QVariant()
    def boundValue(self, pos):
        '''QVariant QSqlQuery.boundValue(int pos)'''
        return QVariant()
    def addBindValue(self, val, type = None):
        '''void QSqlQuery.addBindValue(QVariant val, QSql.ParamType type = QSql.In)'''
    def bindValue(self, placeholder, val, type = None):
        '''void QSqlQuery.bindValue(str placeholder, QVariant val, QSql.ParamType type = QSql.In)'''
    def bindValue(self, pos, val, type = None):
        '''void QSqlQuery.bindValue(int pos, QVariant val, QSql.ParamType type = QSql.In)'''
    def prepare(self, query):
        '''bool QSqlQuery.prepare(str query)'''
        return bool()
    def execBatch(self, mode = None):
        '''bool QSqlQuery.execBatch(QSqlQuery.BatchExecutionMode mode = QSqlQuery.ValuesAsRows)'''
        return bool()
    def clear(self):
        '''void QSqlQuery.clear()'''
    def last(self):
        '''bool QSqlQuery.last()'''
        return bool()
    def first(self):
        '''bool QSqlQuery.first()'''
        return bool()
    def previous(self):
        '''bool QSqlQuery.previous()'''
        return bool()
    def next(self):
        '''bool QSqlQuery.next()'''
        return bool()
    def seek(self, index, relative = False):
        '''bool QSqlQuery.seek(int index, bool relative = False)'''
        return bool()
    def value(self, i):
        '''QVariant QSqlQuery.value(int i)'''
        return QVariant()
    def value(self, name):
        '''QVariant QSqlQuery.value(str name)'''
        return QVariant()
    def exec_(self, query):
        '''bool QSqlQuery.exec_(str query)'''
        return bool()
    def exec_(self):
        '''bool QSqlQuery.exec_()'''
        return bool()
    def setForwardOnly(self, forward):
        '''void QSqlQuery.setForwardOnly(bool forward)'''
    def record(self):
        '''QSqlRecord QSqlQuery.record()'''
        return QSqlRecord()
    def isForwardOnly(self):
        '''bool QSqlQuery.isForwardOnly()'''
        return bool()
    def result(self):
        '''QSqlResult QSqlQuery.result()'''
        return QSqlResult()
    def driver(self):
        '''QSqlDriver QSqlQuery.driver()'''
        return QSqlDriver()
    def size(self):
        '''int QSqlQuery.size()'''
        return int()
    def isSelect(self):
        '''bool QSqlQuery.isSelect()'''
        return bool()
    def lastError(self):
        '''QSqlError QSqlQuery.lastError()'''
        return QSqlError()
    def numRowsAffected(self):
        '''int QSqlQuery.numRowsAffected()'''
        return int()
    def lastQuery(self):
        '''str QSqlQuery.lastQuery()'''
        return str()
    def at(self):
        '''int QSqlQuery.at()'''
        return int()
    def isNull(self, field):
        '''bool QSqlQuery.isNull(int field)'''
        return bool()
    def isNull(self, name):
        '''bool QSqlQuery.isNull(str name)'''
        return bool()
    def isActive(self):
        '''bool QSqlQuery.isActive()'''
        return bool()
    def isValid(self):
        '''bool QSqlQuery.isValid()'''
        return bool()


class QSqlQueryModel(QAbstractTableModel):
    """"""
    def __init__(self, parent = None):
        '''void QSqlQueryModel.__init__(QObject parent = None)'''
    def endRemoveColumns(self):
        '''void QSqlQueryModel.endRemoveColumns()'''
    def beginRemoveColumns(self, parent, first, last):
        '''void QSqlQueryModel.beginRemoveColumns(QModelIndex parent, int first, int last)'''
    def endInsertColumns(self):
        '''void QSqlQueryModel.endInsertColumns()'''
    def beginInsertColumns(self, parent, first, last):
        '''void QSqlQueryModel.beginInsertColumns(QModelIndex parent, int first, int last)'''
    def endRemoveRows(self):
        '''void QSqlQueryModel.endRemoveRows()'''
    def beginRemoveRows(self, parent, first, last):
        '''void QSqlQueryModel.beginRemoveRows(QModelIndex parent, int first, int last)'''
    def endInsertRows(self):
        '''void QSqlQueryModel.endInsertRows()'''
    def beginInsertRows(self, parent, first, last):
        '''void QSqlQueryModel.beginInsertRows(QModelIndex parent, int first, int last)'''
    def endResetModel(self):
        '''void QSqlQueryModel.endResetModel()'''
    def beginResetModel(self):
        '''void QSqlQueryModel.beginResetModel()'''
    def setLastError(self, error):
        '''void QSqlQueryModel.setLastError(QSqlError error)'''
    def indexInQuery(self, item):
        '''QModelIndex QSqlQueryModel.indexInQuery(QModelIndex item)'''
        return QModelIndex()
    def queryChange(self):
        '''void QSqlQueryModel.queryChange()'''
    def canFetchMore(self, parent = QModelIndex()):
        '''bool QSqlQueryModel.canFetchMore(QModelIndex parent = QModelIndex())'''
        return bool()
    def fetchMore(self, parent = QModelIndex()):
        '''void QSqlQueryModel.fetchMore(QModelIndex parent = QModelIndex())'''
    def lastError(self):
        '''QSqlError QSqlQueryModel.lastError()'''
        return QSqlError()
    def clear(self):
        '''void QSqlQueryModel.clear()'''
    def query(self):
        '''QSqlQuery QSqlQueryModel.query()'''
        return QSqlQuery()
    def setQuery(self, query):
        '''void QSqlQueryModel.setQuery(QSqlQuery query)'''
    def setQuery(self, query, db = QSqlDatabase()):
        '''void QSqlQueryModel.setQuery(str query, QSqlDatabase db = QSqlDatabase())'''
    def removeColumns(self, column, count, parent = QModelIndex()):
        '''bool QSqlQueryModel.removeColumns(int column, int count, QModelIndex parent = QModelIndex())'''
        return bool()
    def insertColumns(self, column, count, parent = QModelIndex()):
        '''bool QSqlQueryModel.insertColumns(int column, int count, QModelIndex parent = QModelIndex())'''
        return bool()
    def setHeaderData(self, section, orientation, value, role = None):
        '''bool QSqlQueryModel.setHeaderData(int section, Qt.Orientation orientation, QVariant value, int role = Qt.EditRole)'''
        return bool()
    def headerData(self, section, orientation, role = None):
        '''QVariant QSqlQueryModel.headerData(int section, Qt.Orientation orientation, int role = Qt.DisplayRole)'''
        return QVariant()
    def data(self, item, role = None):
        '''QVariant QSqlQueryModel.data(QModelIndex item, int role = Qt.DisplayRole)'''
        return QVariant()
    def record(self, row):
        '''QSqlRecord QSqlQueryModel.record(int row)'''
        return QSqlRecord()
    def record(self):
        '''QSqlRecord QSqlQueryModel.record()'''
        return QSqlRecord()
    def columnCount(self, parent = QModelIndex()):
        '''int QSqlQueryModel.columnCount(QModelIndex parent = QModelIndex())'''
        return int()
    def rowCount(self, parent = QModelIndex()):
        '''int QSqlQueryModel.rowCount(QModelIndex parent = QModelIndex())'''
        return int()


class QSqlRelationalDelegate(QItemDelegate):
    """"""
    def __init__(self, parent = None):
        '''void QSqlRelationalDelegate.__init__(QObject parent = None)'''
    def setModelData(self, editor, model, index):
        '''void QSqlRelationalDelegate.setModelData(QWidget editor, QAbstractItemModel model, QModelIndex index)'''
    def createEditor(self, parent, option, index):
        '''QWidget QSqlRelationalDelegate.createEditor(QWidget parent, QStyleOptionViewItem option, QModelIndex index)'''
        return QWidget()


class QSqlRelation():
    """"""
    def __init__(self):
        '''void QSqlRelation.__init__()'''
    def __init__(self, aTableName, indexCol, displayCol):
        '''void QSqlRelation.__init__(str aTableName, str indexCol, str displayCol)'''
    def __init__(self):
        '''QSqlRelation QSqlRelation.__init__()'''
        return QSqlRelation()
    def isValid(self):
        '''bool QSqlRelation.isValid()'''
        return bool()
    def displayColumn(self):
        '''str QSqlRelation.displayColumn()'''
        return str()
    def indexColumn(self):
        '''str QSqlRelation.indexColumn()'''
        return str()
    def tableName(self):
        '''str QSqlRelation.tableName()'''
        return str()


class QSqlTableModel(QSqlQueryModel):
    """"""
    # Enum QSqlTableModel.EditStrategy
    OnFieldChange = 0
    OnRowChange = 0
    OnManualSubmit = 0

    def __init__(self, parent = None, db = QSqlDatabase()):
        '''void QSqlTableModel.__init__(QObject parent = None, QSqlDatabase db = QSqlDatabase())'''
    def primaryValues(self, row):
        '''QSqlRecord QSqlTableModel.primaryValues(int row)'''
        return QSqlRecord()
    def record(self):
        '''QSqlRecord QSqlTableModel.record()'''
        return QSqlRecord()
    def record(self, row):
        '''QSqlRecord QSqlTableModel.record(int row)'''
        return QSqlRecord()
    def selectRow(self, row):
        '''bool QSqlTableModel.selectRow(int row)'''
        return bool()
    def indexInQuery(self, item):
        '''QModelIndex QSqlTableModel.indexInQuery(QModelIndex item)'''
        return QModelIndex()
    def setQuery(self, query):
        '''void QSqlTableModel.setQuery(QSqlQuery query)'''
    def setPrimaryKey(self, key):
        '''void QSqlTableModel.setPrimaryKey(QSqlIndex key)'''
    def selectStatement(self):
        '''str QSqlTableModel.selectStatement()'''
        return str()
    def orderByClause(self):
        '''str QSqlTableModel.orderByClause()'''
        return str()
    def deleteRowFromTable(self, row):
        '''bool QSqlTableModel.deleteRowFromTable(int row)'''
        return bool()
    def insertRowIntoTable(self, values):
        '''bool QSqlTableModel.insertRowIntoTable(QSqlRecord values)'''
        return bool()
    def updateRowInTable(self, row, values):
        '''bool QSqlTableModel.updateRowInTable(int row, QSqlRecord values)'''
        return bool()
    beforeDelete = pyqtSignal() # void beforeDelete(int) - signal
    beforeUpdate = pyqtSignal() # void beforeUpdate(int,QSqlRecordamp;) - signal
    beforeInsert = pyqtSignal() # void beforeInsert(QSqlRecordamp;) - signal
    primeInsert = pyqtSignal() # void primeInsert(int,QSqlRecordamp;) - signal
    def revertAll(self):
        '''void QSqlTableModel.revertAll()'''
    def submitAll(self):
        '''bool QSqlTableModel.submitAll()'''
        return bool()
    def revert(self):
        '''void QSqlTableModel.revert()'''
    def submit(self):
        '''bool QSqlTableModel.submit()'''
        return bool()
    def revertRow(self, row):
        '''void QSqlTableModel.revertRow(int row)'''
    def setRecord(self, row, record):
        '''bool QSqlTableModel.setRecord(int row, QSqlRecord record)'''
        return bool()
    def insertRecord(self, row, record):
        '''bool QSqlTableModel.insertRecord(int row, QSqlRecord record)'''
        return bool()
    def insertRows(self, row, count, parent = QModelIndex()):
        '''bool QSqlTableModel.insertRows(int row, int count, QModelIndex parent = QModelIndex())'''
        return bool()
    def removeRows(self, row, count, parent = QModelIndex()):
        '''bool QSqlTableModel.removeRows(int row, int count, QModelIndex parent = QModelIndex())'''
        return bool()
    def removeColumns(self, column, count, parent = QModelIndex()):
        '''bool QSqlTableModel.removeColumns(int column, int count, QModelIndex parent = QModelIndex())'''
        return bool()
    def rowCount(self, parent = QModelIndex()):
        '''int QSqlTableModel.rowCount(QModelIndex parent = QModelIndex())'''
        return int()
    def setFilter(self, filter):
        '''void QSqlTableModel.setFilter(str filter)'''
    def filter(self):
        '''str QSqlTableModel.filter()'''
        return str()
    def setSort(self, column, order):
        '''void QSqlTableModel.setSort(int column, Qt.SortOrder order)'''
    def sort(self, column, order):
        '''void QSqlTableModel.sort(int column, Qt.SortOrder order)'''
    def fieldIndex(self, fieldName):
        '''int QSqlTableModel.fieldIndex(str fieldName)'''
        return int()
    def database(self):
        '''QSqlDatabase QSqlTableModel.database()'''
        return QSqlDatabase()
    def primaryKey(self):
        '''QSqlIndex QSqlTableModel.primaryKey()'''
        return QSqlIndex()
    def editStrategy(self):
        '''QSqlTableModel.EditStrategy QSqlTableModel.editStrategy()'''
        return QSqlTableModel.EditStrategy()
    def setEditStrategy(self, strategy):
        '''void QSqlTableModel.setEditStrategy(QSqlTableModel.EditStrategy strategy)'''
    def clear(self):
        '''void QSqlTableModel.clear()'''
    def isDirty(self, index):
        '''bool QSqlTableModel.isDirty(QModelIndex index)'''
        return bool()
    def isDirty(self):
        '''bool QSqlTableModel.isDirty()'''
        return bool()
    def headerData(self, section, orientation, role = None):
        '''QVariant QSqlTableModel.headerData(int section, Qt.Orientation orientation, int role = Qt.DisplayRole)'''
        return QVariant()
    def setData(self, index, value, role = None):
        '''bool QSqlTableModel.setData(QModelIndex index, QVariant value, int role = Qt.EditRole)'''
        return bool()
    def data(self, index, role = None):
        '''QVariant QSqlTableModel.data(QModelIndex index, int role = Qt.DisplayRole)'''
        return QVariant()
    def flags(self, index):
        '''Qt.ItemFlags QSqlTableModel.flags(QModelIndex index)'''
        return Qt.ItemFlags()
    def tableName(self):
        '''str QSqlTableModel.tableName()'''
        return str()
    def setTable(self, tableName):
        '''void QSqlTableModel.setTable(str tableName)'''
    def select(self):
        '''bool QSqlTableModel.select()'''
        return bool()


class QSqlRelationalTableModel(QSqlTableModel):
    """"""
    # Enum QSqlRelationalTableModel.JoinMode
    InnerJoin = 0
    LeftJoin = 0

    def __init__(self, parent = None, db = QSqlDatabase()):
        '''void QSqlRelationalTableModel.__init__(QObject parent = None, QSqlDatabase db = QSqlDatabase())'''
    def setJoinMode(self, joinMode):
        '''void QSqlRelationalTableModel.setJoinMode(QSqlRelationalTableModel.JoinMode joinMode)'''
    def insertRowIntoTable(self, values):
        '''bool QSqlRelationalTableModel.insertRowIntoTable(QSqlRecord values)'''
        return bool()
    def orderByClause(self):
        '''str QSqlRelationalTableModel.orderByClause()'''
        return str()
    def updateRowInTable(self, row, values):
        '''bool QSqlRelationalTableModel.updateRowInTable(int row, QSqlRecord values)'''
        return bool()
    def selectStatement(self):
        '''str QSqlRelationalTableModel.selectStatement()'''
        return str()
    def removeColumns(self, column, count, parent = QModelIndex()):
        '''bool QSqlRelationalTableModel.removeColumns(int column, int count, QModelIndex parent = QModelIndex())'''
        return bool()
    def revertRow(self, row):
        '''void QSqlRelationalTableModel.revertRow(int row)'''
    def relationModel(self, column):
        '''QSqlTableModel QSqlRelationalTableModel.relationModel(int column)'''
        return QSqlTableModel()
    def relation(self, column):
        '''QSqlRelation QSqlRelationalTableModel.relation(int column)'''
        return QSqlRelation()
    def setRelation(self, column, relation):
        '''void QSqlRelationalTableModel.setRelation(int column, QSqlRelation relation)'''
    def setTable(self, tableName):
        '''void QSqlRelationalTableModel.setTable(str tableName)'''
    def select(self):
        '''bool QSqlRelationalTableModel.select()'''
        return bool()
    def clear(self):
        '''void QSqlRelationalTableModel.clear()'''
    def setData(self, index, value, role = None):
        '''bool QSqlRelationalTableModel.setData(QModelIndex index, QVariant value, int role = Qt.EditRole)'''
        return bool()
    def data(self, index, role = None):
        '''QVariant QSqlRelationalTableModel.data(QModelIndex index, int role = Qt.DisplayRole)'''
        return QVariant()


class QSqlResult():
    """"""
    # Enum QSqlResult.BindingSyntax
    PositionalBinding = 0
    NamedBinding = 0

    def __init__(self, db):
        '''void QSqlResult.__init__(QSqlDriver db)'''
    def lastInsertId(self):
        '''QVariant QSqlResult.lastInsertId()'''
        return QVariant()
    def record(self):
        '''QSqlRecord QSqlResult.record()'''
        return QSqlRecord()
    def numRowsAffected(self):
        '''abstract int QSqlResult.numRowsAffected()'''
        return int()
    def size(self):
        '''abstract int QSqlResult.size()'''
        return int()
    def fetchLast(self):
        '''abstract bool QSqlResult.fetchLast()'''
        return bool()
    def fetchFirst(self):
        '''abstract bool QSqlResult.fetchFirst()'''
        return bool()
    def fetchPrevious(self):
        '''bool QSqlResult.fetchPrevious()'''
        return bool()
    def fetchNext(self):
        '''bool QSqlResult.fetchNext()'''
        return bool()
    def fetch(self, i):
        '''abstract bool QSqlResult.fetch(int i)'''
        return bool()
    def reset(self, sqlquery):
        '''abstract bool QSqlResult.reset(str sqlquery)'''
        return bool()
    def isNull(self, i):
        '''abstract bool QSqlResult.isNull(int i)'''
        return bool()
    def data(self, i):
        '''abstract QVariant QSqlResult.data(int i)'''
        return QVariant()
    def bindingSyntax(self):
        '''QSqlResult.BindingSyntax QSqlResult.bindingSyntax()'''
        return QSqlResult.BindingSyntax()
    def hasOutValues(self):
        '''bool QSqlResult.hasOutValues()'''
        return bool()
    def clear(self):
        '''void QSqlResult.clear()'''
    def boundValueName(self, pos):
        '''str QSqlResult.boundValueName(int pos)'''
        return str()
    def executedQuery(self):
        '''str QSqlResult.executedQuery()'''
        return str()
    def boundValues(self):
        '''list-of-QVariant QSqlResult.boundValues()'''
        return [QVariant()]
    def boundValueCount(self):
        '''int QSqlResult.boundValueCount()'''
        return int()
    def bindValueType(self, placeholder):
        '''QSql.ParamType QSqlResult.bindValueType(str placeholder)'''
        return QSql.ParamType()
    def bindValueType(self, pos):
        '''QSql.ParamType QSqlResult.bindValueType(int pos)'''
        return QSql.ParamType()
    def boundValue(self, placeholder):
        '''QVariant QSqlResult.boundValue(str placeholder)'''
        return QVariant()
    def boundValue(self, pos):
        '''QVariant QSqlResult.boundValue(int pos)'''
        return QVariant()
    def addBindValue(self, val, type):
        '''void QSqlResult.addBindValue(QVariant val, QSql.ParamType type)'''
    def bindValue(self, pos, val, type):
        '''void QSqlResult.bindValue(int pos, QVariant val, QSql.ParamType type)'''
    def bindValue(self, placeholder, val, type):
        '''void QSqlResult.bindValue(str placeholder, QVariant val, QSql.ParamType type)'''
    def savePrepare(self, sqlquery):
        '''bool QSqlResult.savePrepare(str sqlquery)'''
        return bool()
    def prepare(self, query):
        '''bool QSqlResult.prepare(str query)'''
        return bool()
    def exec_(self):
        '''bool QSqlResult.exec_()'''
        return bool()
    def setForwardOnly(self, forward):
        '''void QSqlResult.setForwardOnly(bool forward)'''
    def setSelect(self, s):
        '''void QSqlResult.setSelect(bool s)'''
    def setQuery(self, query):
        '''void QSqlResult.setQuery(str query)'''
    def setLastError(self, e):
        '''void QSqlResult.setLastError(QSqlError e)'''
    def setActive(self, a):
        '''void QSqlResult.setActive(bool a)'''
    def setAt(self, at):
        '''void QSqlResult.setAt(int at)'''
    def driver(self):
        '''QSqlDriver QSqlResult.driver()'''
        return QSqlDriver()
    def isForwardOnly(self):
        '''bool QSqlResult.isForwardOnly()'''
        return bool()
    def isSelect(self):
        '''bool QSqlResult.isSelect()'''
        return bool()
    def isActive(self):
        '''bool QSqlResult.isActive()'''
        return bool()
    def isValid(self):
        '''bool QSqlResult.isValid()'''
        return bool()
    def lastError(self):
        '''QSqlError QSqlResult.lastError()'''
        return QSqlError()
    def lastQuery(self):
        '''str QSqlResult.lastQuery()'''
        return str()
    def at(self):
        '''int QSqlResult.at()'''
        return int()
    def handle(self):
        '''QVariant QSqlResult.handle()'''
        return QVariant()





class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QAbstractPrintDialog(QDialog):
    """"""
    # Enum QAbstractPrintDialog.PrintDialogOption
    __kdevpythondocumentation_builtin_None = 0
    None_ = 0
    PrintToFile = 0
    PrintSelection = 0
    PrintPageRange = 0
    PrintCollateCopies = 0
    PrintShowPageSize = 0
    PrintCurrentPage = 0

    # Enum QAbstractPrintDialog.PrintRange
    AllPages = 0
    Selection = 0
    PageRange = 0
    CurrentPage = 0

    def __init__(self, printer, parent = None):
        '''void QAbstractPrintDialog.__init__(QPrinter printer, QWidget parent = None)'''
    def setOptionTabs(self, tabs):
        '''void QAbstractPrintDialog.setOptionTabs(list-of-QWidget tabs)'''
    def printer(self):
        '''QPrinter QAbstractPrintDialog.printer()'''
        return QPrinter()
    def toPage(self):
        '''int QAbstractPrintDialog.toPage()'''
        return int()
    def fromPage(self):
        '''int QAbstractPrintDialog.fromPage()'''
        return int()
    def setFromTo(self, fromPage, toPage):
        '''void QAbstractPrintDialog.setFromTo(int fromPage, int toPage)'''
    def maxPage(self):
        '''int QAbstractPrintDialog.maxPage()'''
        return int()
    def minPage(self):
        '''int QAbstractPrintDialog.minPage()'''
        return int()
    def setMinMax(self, min, max):
        '''void QAbstractPrintDialog.setMinMax(int min, int max)'''
    def printRange(self):
        '''QAbstractPrintDialog.PrintRange QAbstractPrintDialog.printRange()'''
        return QAbstractPrintDialog.PrintRange()
    def setPrintRange(self, range):
        '''void QAbstractPrintDialog.setPrintRange(QAbstractPrintDialog.PrintRange range)'''
    def exec_(self):
        '''abstract int QAbstractPrintDialog.exec_()'''
        return int()
    class PrintDialogOptions():
        """"""
        def __init__(self):
            '''QAbstractPrintDialog.PrintDialogOptions QAbstractPrintDialog.PrintDialogOptions.__init__()'''
            return QAbstractPrintDialog.PrintDialogOptions()
        def __init__(self):
            '''int QAbstractPrintDialog.PrintDialogOptions.__init__()'''
            return int()
        def __init__(self):
            '''void QAbstractPrintDialog.PrintDialogOptions.__init__()'''
        def __bool__(self):
            '''int QAbstractPrintDialog.PrintDialogOptions.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QAbstractPrintDialog.PrintDialogOptions.__ne__(QAbstractPrintDialog.PrintDialogOptions f)'''
            return bool()
        def __eq__(self, f):
            '''bool QAbstractPrintDialog.PrintDialogOptions.__eq__(QAbstractPrintDialog.PrintDialogOptions f)'''
            return bool()
        def __invert__(self):
            '''QAbstractPrintDialog.PrintDialogOptions QAbstractPrintDialog.PrintDialogOptions.__invert__()'''
            return QAbstractPrintDialog.PrintDialogOptions()
        def __and__(self, mask):
            '''QAbstractPrintDialog.PrintDialogOptions QAbstractPrintDialog.PrintDialogOptions.__and__(int mask)'''
            return QAbstractPrintDialog.PrintDialogOptions()
        def __xor__(self, f):
            '''QAbstractPrintDialog.PrintDialogOptions QAbstractPrintDialog.PrintDialogOptions.__xor__(QAbstractPrintDialog.PrintDialogOptions f)'''
            return QAbstractPrintDialog.PrintDialogOptions()
        def __xor__(self, f):
            '''QAbstractPrintDialog.PrintDialogOptions QAbstractPrintDialog.PrintDialogOptions.__xor__(int f)'''
            return QAbstractPrintDialog.PrintDialogOptions()
        def __or__(self, f):
            '''QAbstractPrintDialog.PrintDialogOptions QAbstractPrintDialog.PrintDialogOptions.__or__(QAbstractPrintDialog.PrintDialogOptions f)'''
            return QAbstractPrintDialog.PrintDialogOptions()
        def __or__(self, f):
            '''QAbstractPrintDialog.PrintDialogOptions QAbstractPrintDialog.PrintDialogOptions.__or__(int f)'''
            return QAbstractPrintDialog.PrintDialogOptions()
        def __int__(self):
            '''int QAbstractPrintDialog.PrintDialogOptions.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QAbstractPrintDialog.PrintDialogOptions QAbstractPrintDialog.PrintDialogOptions.__ixor__(QAbstractPrintDialog.PrintDialogOptions f)'''
            return QAbstractPrintDialog.PrintDialogOptions()
        def __ior__(self, f):
            '''QAbstractPrintDialog.PrintDialogOptions QAbstractPrintDialog.PrintDialogOptions.__ior__(QAbstractPrintDialog.PrintDialogOptions f)'''
            return QAbstractPrintDialog.PrintDialogOptions()
        def __iand__(self, mask):
            '''QAbstractPrintDialog.PrintDialogOptions QAbstractPrintDialog.PrintDialogOptions.__iand__(int mask)'''
            return QAbstractPrintDialog.PrintDialogOptions()


class QPageSetupDialog(QDialog):
    """"""
    def __init__(self, printer, parent = None):
        '''void QPageSetupDialog.__init__(QPrinter printer, QWidget parent = None)'''
    def __init__(self, parent = None):
        '''void QPageSetupDialog.__init__(QWidget parent = None)'''
    def printer(self):
        '''QPrinter QPageSetupDialog.printer()'''
        return QPrinter()
    def done(self, result):
        '''void QPageSetupDialog.done(int result)'''
    def open(self):
        '''void QPageSetupDialog.open()'''
    def open(self, slot):
        '''void QPageSetupDialog.open(slot slot)'''
    def exec_(self):
        '''int QPageSetupDialog.exec_()'''
        return int()
    def setVisible(self, visible):
        '''void QPageSetupDialog.setVisible(bool visible)'''


class QPrintDialog(QAbstractPrintDialog):
    """"""
    def __init__(self, printer, parent = None):
        '''void QPrintDialog.__init__(QPrinter printer, QWidget parent = None)'''
    def __init__(self, parent = None):
        '''void QPrintDialog.__init__(QWidget parent = None)'''
    accepted = pyqtSignal() # void accepted() - signal
    accepted = pyqtSignal() # void accepted(QPrinter*) - signal
    def open(self):
        '''void QPrintDialog.open()'''
    def open(self, slot):
        '''void QPrintDialog.open(slot slot)'''
    def setVisible(self, visible):
        '''void QPrintDialog.setVisible(bool visible)'''
    def options(self):
        '''QAbstractPrintDialog.PrintDialogOptions QPrintDialog.options()'''
        return QAbstractPrintDialog.PrintDialogOptions()
    def setOptions(self, options):
        '''void QPrintDialog.setOptions(QAbstractPrintDialog.PrintDialogOptions options)'''
    def testOption(self, option):
        '''bool QPrintDialog.testOption(QAbstractPrintDialog.PrintDialogOption option)'''
        return bool()
    def setOption(self, option, on = True):
        '''void QPrintDialog.setOption(QAbstractPrintDialog.PrintDialogOption option, bool on = True)'''
    def done(self, result):
        '''void QPrintDialog.done(int result)'''
    def accept(self):
        '''void QPrintDialog.accept()'''
    def exec_(self):
        '''int QPrintDialog.exec_()'''
        return int()


class QPrintEngine():
    """"""
    # Enum QPrintEngine.PrintEnginePropertyKey
    PPK_CollateCopies = 0
    PPK_ColorMode = 0
    PPK_Creator = 0
    PPK_DocumentName = 0
    PPK_FullPage = 0
    PPK_NumberOfCopies = 0
    PPK_Orientation = 0
    PPK_OutputFileName = 0
    PPK_PageOrder = 0
    PPK_PageRect = 0
    PPK_PageSize = 0
    PPK_PaperRect = 0
    PPK_PaperSource = 0
    PPK_PrinterName = 0
    PPK_PrinterProgram = 0
    PPK_Resolution = 0
    PPK_SelectionOption = 0
    PPK_SupportedResolutions = 0
    PPK_WindowsPageSize = 0
    PPK_FontEmbedding = 0
    PPK_Duplex = 0
    PPK_PaperSources = 0
    PPK_CustomPaperSize = 0
    PPK_PageMargins = 0
    PPK_PaperSize = 0
    PPK_CopyCount = 0
    PPK_SupportsMultipleCopies = 0
    PPK_PaperName = 0
    PPK_QPageSize = 0
    PPK_QPageMargins = 0
    PPK_QPageLayout = 0
    PPK_CustomBase = 0

    def __init__(self):
        '''void QPrintEngine.__init__()'''
    def __init__(self):
        '''QPrintEngine QPrintEngine.__init__()'''
        return QPrintEngine()
    def printerState(self):
        '''abstract QPrinter.PrinterState QPrintEngine.printerState()'''
        return QPrinter.PrinterState()
    def metric(self):
        '''abstract QPaintDevice.PaintDeviceMetric QPrintEngine.metric()'''
        return QPaintDevice.PaintDeviceMetric()
    def abort(self):
        '''abstract bool QPrintEngine.abort()'''
        return bool()
    def newPage(self):
        '''abstract bool QPrintEngine.newPage()'''
        return bool()
    def property(self, key):
        '''abstract QVariant QPrintEngine.property(QPrintEngine.PrintEnginePropertyKey key)'''
        return QVariant()
    def setProperty(self, key, value):
        '''abstract void QPrintEngine.setProperty(QPrintEngine.PrintEnginePropertyKey key, QVariant value)'''


class QPrinter(QPagedPaintDevice):
    """"""
    # Enum QPrinter.DuplexMode
    DuplexNone = 0
    DuplexAuto = 0
    DuplexLongSide = 0
    DuplexShortSide = 0

    # Enum QPrinter.Unit
    Millimeter = 0
    Point = 0
    Inch = 0
    Pica = 0
    Didot = 0
    Cicero = 0
    DevicePixel = 0

    # Enum QPrinter.PrintRange
    AllPages = 0
    Selection = 0
    PageRange = 0
    CurrentPage = 0

    # Enum QPrinter.OutputFormat
    NativeFormat = 0
    PdfFormat = 0

    # Enum QPrinter.PrinterState
    Idle = 0
    Active = 0
    Aborted = 0
    Error = 0

    # Enum QPrinter.PaperSource
    OnlyOne = 0
    Lower = 0
    Middle = 0
    Manual = 0
    Envelope = 0
    EnvelopeManual = 0
    Auto = 0
    Tractor = 0
    SmallFormat = 0
    LargeFormat = 0
    LargeCapacity = 0
    Cassette = 0
    FormSource = 0
    MaxPageSource = 0
    Upper = 0
    CustomSource = 0
    LastPaperSource = 0

    # Enum QPrinter.ColorMode
    GrayScale = 0
    Color = 0

    # Enum QPrinter.PageOrder
    FirstPageFirst = 0
    LastPageFirst = 0

    # Enum QPrinter.Orientation
    Portrait = 0
    Landscape = 0

    # Enum QPrinter.PrinterMode
    ScreenResolution = 0
    PrinterResolution = 0
    HighResolution = 0

    def __init__(self, mode = None):
        '''void QPrinter.__init__(QPrinter.PrinterMode mode = QPrinter.ScreenResolution)'''
    def __init__(self, printer, mode = None):
        '''void QPrinter.__init__(QPrinterInfo printer, QPrinter.PrinterMode mode = QPrinter.ScreenResolution)'''
    def paperName(self):
        '''str QPrinter.paperName()'''
        return str()
    def setPaperName(self, paperName):
        '''void QPrinter.setPaperName(str paperName)'''
    def setEngines(self, printEngine, paintEngine):
        '''void QPrinter.setEngines(QPrintEngine printEngine, QPaintEngine paintEngine)'''
    def metric(self):
        '''QPaintDevice.PaintDeviceMetric QPrinter.metric()'''
        return QPaintDevice.PaintDeviceMetric()
    def getPageMargins(self, left, top, right, bottom, unit):
        '''void QPrinter.getPageMargins(float left, float top, float right, float bottom, QPrinter.Unit unit)'''
    def setPageMargins(self, left, top, right, bottom, unit):
        '''void QPrinter.setPageMargins(float left, float top, float right, float bottom, QPrinter.Unit unit)'''
    def setMargins(self, m):
        '''void QPrinter.setMargins(QPagedPaintDevice.Margins m)'''
    def printRange(self):
        '''QPrinter.PrintRange QPrinter.printRange()'''
        return QPrinter.PrintRange()
    def setPrintRange(self, range):
        '''void QPrinter.setPrintRange(QPrinter.PrintRange range)'''
    def toPage(self):
        '''int QPrinter.toPage()'''
        return int()
    def fromPage(self):
        '''int QPrinter.fromPage()'''
        return int()
    def setFromTo(self, fromPage, toPage):
        '''void QPrinter.setFromTo(int fromPage, int toPage)'''
    def printEngine(self):
        '''QPrintEngine QPrinter.printEngine()'''
        return QPrintEngine()
    def paintEngine(self):
        '''QPaintEngine QPrinter.paintEngine()'''
        return QPaintEngine()
    def printerState(self):
        '''QPrinter.PrinterState QPrinter.printerState()'''
        return QPrinter.PrinterState()
    def abort(self):
        '''bool QPrinter.abort()'''
        return bool()
    def newPage(self):
        '''bool QPrinter.newPage()'''
        return bool()
    def setPrinterSelectionOption(self):
        '''str QPrinter.setPrinterSelectionOption()'''
        return str()
    def printerSelectionOption(self):
        '''str QPrinter.printerSelectionOption()'''
        return str()
    def pageRect(self):
        '''QRect QPrinter.pageRect()'''
        return QRect()
    def pageRect(self):
        '''QPrinter.Unit QPrinter.pageRect()'''
        return QPrinter.Unit()
    def paperRect(self):
        '''QRect QPrinter.paperRect()'''
        return QRect()
    def paperRect(self):
        '''QPrinter.Unit QPrinter.paperRect()'''
        return QPrinter.Unit()
    def doubleSidedPrinting(self):
        '''bool QPrinter.doubleSidedPrinting()'''
        return bool()
    def setDoubleSidedPrinting(self, enable):
        '''void QPrinter.setDoubleSidedPrinting(bool enable)'''
    def fontEmbeddingEnabled(self):
        '''bool QPrinter.fontEmbeddingEnabled()'''
        return bool()
    def setFontEmbeddingEnabled(self, enable):
        '''void QPrinter.setFontEmbeddingEnabled(bool enable)'''
    def supportedResolutions(self):
        '''list-of-int QPrinter.supportedResolutions()'''
        return [int()]
    def duplex(self):
        '''QPrinter.DuplexMode QPrinter.duplex()'''
        return QPrinter.DuplexMode()
    def setDuplex(self, duplex):
        '''void QPrinter.setDuplex(QPrinter.DuplexMode duplex)'''
    def paperSource(self):
        '''QPrinter.PaperSource QPrinter.paperSource()'''
        return QPrinter.PaperSource()
    def setPaperSource(self):
        '''QPrinter.PaperSource QPrinter.setPaperSource()'''
        return QPrinter.PaperSource()
    def supportsMultipleCopies(self):
        '''bool QPrinter.supportsMultipleCopies()'''
        return bool()
    def copyCount(self):
        '''int QPrinter.copyCount()'''
        return int()
    def setCopyCount(self):
        '''int QPrinter.setCopyCount()'''
        return int()
    def fullPage(self):
        '''bool QPrinter.fullPage()'''
        return bool()
    def setFullPage(self):
        '''bool QPrinter.setFullPage()'''
        return bool()
    def collateCopies(self):
        '''bool QPrinter.collateCopies()'''
        return bool()
    def setCollateCopies(self, collate):
        '''void QPrinter.setCollateCopies(bool collate)'''
    def colorMode(self):
        '''QPrinter.ColorMode QPrinter.colorMode()'''
        return QPrinter.ColorMode()
    def setColorMode(self):
        '''QPrinter.ColorMode QPrinter.setColorMode()'''
        return QPrinter.ColorMode()
    def resolution(self):
        '''int QPrinter.resolution()'''
        return int()
    def setResolution(self):
        '''int QPrinter.setResolution()'''
        return int()
    def pageOrder(self):
        '''QPrinter.PageOrder QPrinter.pageOrder()'''
        return QPrinter.PageOrder()
    def setPageOrder(self):
        '''QPrinter.PageOrder QPrinter.setPageOrder()'''
        return QPrinter.PageOrder()
    def paperSize(self):
        '''QPagedPaintDevice.PageSize QPrinter.paperSize()'''
        return QPagedPaintDevice.PageSize()
    def paperSize(self, unit):
        '''QSizeF QPrinter.paperSize(QPrinter.Unit unit)'''
        return QSizeF()
    def setPaperSize(self):
        '''QPagedPaintDevice.PageSize QPrinter.setPaperSize()'''
        return QPagedPaintDevice.PageSize()
    def setPaperSize(self, paperSize, unit):
        '''void QPrinter.setPaperSize(QSizeF paperSize, QPrinter.Unit unit)'''
    def setPageSizeMM(self, size):
        '''void QPrinter.setPageSizeMM(QSizeF size)'''
    def orientation(self):
        '''QPrinter.Orientation QPrinter.orientation()'''
        return QPrinter.Orientation()
    def setOrientation(self):
        '''QPrinter.Orientation QPrinter.setOrientation()'''
        return QPrinter.Orientation()
    def creator(self):
        '''str QPrinter.creator()'''
        return str()
    def setCreator(self):
        '''str QPrinter.setCreator()'''
        return str()
    def docName(self):
        '''str QPrinter.docName()'''
        return str()
    def setDocName(self):
        '''str QPrinter.setDocName()'''
        return str()
    def printProgram(self):
        '''str QPrinter.printProgram()'''
        return str()
    def setPrintProgram(self):
        '''str QPrinter.setPrintProgram()'''
        return str()
    def outputFileName(self):
        '''str QPrinter.outputFileName()'''
        return str()
    def setOutputFileName(self):
        '''str QPrinter.setOutputFileName()'''
        return str()
    def isValid(self):
        '''bool QPrinter.isValid()'''
        return bool()
    def printerName(self):
        '''str QPrinter.printerName()'''
        return str()
    def setPrinterName(self):
        '''str QPrinter.setPrinterName()'''
        return str()
    def outputFormat(self):
        '''QPrinter.OutputFormat QPrinter.outputFormat()'''
        return QPrinter.OutputFormat()
    def setOutputFormat(self, format):
        '''void QPrinter.setOutputFormat(QPrinter.OutputFormat format)'''


class QPrinterInfo():
    """"""
    def __init__(self):
        '''void QPrinterInfo.__init__()'''
    def __init__(self, src):
        '''void QPrinterInfo.__init__(QPrinterInfo src)'''
    def __init__(self, printer):
        '''void QPrinterInfo.__init__(QPrinter printer)'''
    def supportedDuplexModes(self):
        '''list-of-QPrinter.DuplexMode QPrinterInfo.supportedDuplexModes()'''
        return [QPrinter.DuplexMode()]
    def defaultDuplexMode(self):
        '''QPrinter.DuplexMode QPrinterInfo.defaultDuplexMode()'''
        return QPrinter.DuplexMode()
    def defaultPrinterName(self):
        '''static str QPrinterInfo.defaultPrinterName()'''
        return str()
    def availablePrinterNames(self):
        '''static list-of-str QPrinterInfo.availablePrinterNames()'''
        return [str()]
    def supportedResolutions(self):
        '''list-of-int QPrinterInfo.supportedResolutions()'''
        return [int()]
    def maximumPhysicalPageSize(self):
        '''QPageSize QPrinterInfo.maximumPhysicalPageSize()'''
        return QPageSize()
    def minimumPhysicalPageSize(self):
        '''QPageSize QPrinterInfo.minimumPhysicalPageSize()'''
        return QPageSize()
    def supportsCustomPageSizes(self):
        '''bool QPrinterInfo.supportsCustomPageSizes()'''
        return bool()
    def defaultPageSize(self):
        '''QPageSize QPrinterInfo.defaultPageSize()'''
        return QPageSize()
    def supportedPageSizes(self):
        '''list-of-QPageSize QPrinterInfo.supportedPageSizes()'''
        return [QPageSize()]
    def state(self):
        '''QPrinter.PrinterState QPrinterInfo.state()'''
        return QPrinter.PrinterState()
    def isRemote(self):
        '''bool QPrinterInfo.isRemote()'''
        return bool()
    def printerInfo(self, printerName):
        '''static QPrinterInfo QPrinterInfo.printerInfo(str printerName)'''
        return QPrinterInfo()
    def makeAndModel(self):
        '''str QPrinterInfo.makeAndModel()'''
        return str()
    def location(self):
        '''str QPrinterInfo.location()'''
        return str()
    def description(self):
        '''str QPrinterInfo.description()'''
        return str()
    def defaultPrinter(self):
        '''static QPrinterInfo QPrinterInfo.defaultPrinter()'''
        return QPrinterInfo()
    def availablePrinters(self):
        '''static list-of-QPrinterInfo QPrinterInfo.availablePrinters()'''
        return [QPrinterInfo()]
    def supportedSizesWithNames(self):
        '''list-of-tuple-of-QString-QSizeF QPrinterInfo.supportedSizesWithNames()'''
        return [tuple-of-str-QSizeF()]
    def supportedPaperSizes(self):
        '''list-of-QPagedPaintDevice.PageSize QPrinterInfo.supportedPaperSizes()'''
        return [QPagedPaintDevice.PageSize()]
    def isDefault(self):
        '''bool QPrinterInfo.isDefault()'''
        return bool()
    def isNull(self):
        '''bool QPrinterInfo.isNull()'''
        return bool()
    def printerName(self):
        '''str QPrinterInfo.printerName()'''
        return str()


class QPrintPreviewDialog(QDialog):
    """"""
    def __init__(self, parent = None, flags = 0):
        '''void QPrintPreviewDialog.__init__(QWidget parent = None, Qt.WindowFlags flags = 0)'''
    def __init__(self, printer, parent = None, flags = 0):
        '''void QPrintPreviewDialog.__init__(QPrinter printer, QWidget parent = None, Qt.WindowFlags flags = 0)'''
    paintRequested = pyqtSignal() # void paintRequested(QPrinter*) - signal
    def done(self, result):
        '''void QPrintPreviewDialog.done(int result)'''
    def printer(self):
        '''QPrinter QPrintPreviewDialog.printer()'''
        return QPrinter()
    def open(self):
        '''void QPrintPreviewDialog.open()'''
    def open(self, slot):
        '''void QPrintPreviewDialog.open(slot slot)'''
    def setVisible(self, visible):
        '''void QPrintPreviewDialog.setVisible(bool visible)'''


class QPrintPreviewWidget(QWidget):
    """"""
    # Enum QPrintPreviewWidget.ZoomMode
    CustomZoom = 0
    FitToWidth = 0
    FitInView = 0

    # Enum QPrintPreviewWidget.ViewMode
    SinglePageView = 0
    FacingPagesView = 0
    AllPagesView = 0

    def __init__(self, printer, parent = None, flags = 0):
        '''void QPrintPreviewWidget.__init__(QPrinter printer, QWidget parent = None, Qt.WindowFlags flags = 0)'''
    def __init__(self, parent = None, flags = 0):
        '''void QPrintPreviewWidget.__init__(QWidget parent = None, Qt.WindowFlags flags = 0)'''
    def pageCount(self):
        '''int QPrintPreviewWidget.pageCount()'''
        return int()
    previewChanged = pyqtSignal() # void previewChanged() - signal
    paintRequested = pyqtSignal() # void paintRequested(QPrinter*) - signal
    def updatePreview(self):
        '''void QPrintPreviewWidget.updatePreview()'''
    def setAllPagesViewMode(self):
        '''void QPrintPreviewWidget.setAllPagesViewMode()'''
    def setFacingPagesViewMode(self):
        '''void QPrintPreviewWidget.setFacingPagesViewMode()'''
    def setSinglePageViewMode(self):
        '''void QPrintPreviewWidget.setSinglePageViewMode()'''
    def setPortraitOrientation(self):
        '''void QPrintPreviewWidget.setPortraitOrientation()'''
    def setLandscapeOrientation(self):
        '''void QPrintPreviewWidget.setLandscapeOrientation()'''
    def fitInView(self):
        '''void QPrintPreviewWidget.fitInView()'''
    def fitToWidth(self):
        '''void QPrintPreviewWidget.fitToWidth()'''
    def setCurrentPage(self, pageNumber):
        '''void QPrintPreviewWidget.setCurrentPage(int pageNumber)'''
    def setZoomMode(self, zoomMode):
        '''void QPrintPreviewWidget.setZoomMode(QPrintPreviewWidget.ZoomMode zoomMode)'''
    def setViewMode(self, viewMode):
        '''void QPrintPreviewWidget.setViewMode(QPrintPreviewWidget.ViewMode viewMode)'''
    def setOrientation(self, orientation):
        '''void QPrintPreviewWidget.setOrientation(QPrinter.Orientation orientation)'''
    def setZoomFactor(self, zoomFactor):
        '''void QPrintPreviewWidget.setZoomFactor(float zoomFactor)'''
    def zoomOut(self, factor = None):
        '''void QPrintPreviewWidget.zoomOut(float factor = 1.1)'''
    def zoomIn(self, factor = None):
        '''void QPrintPreviewWidget.zoomIn(float factor = 1.1)'''
    def print_(self):
        '''void QPrintPreviewWidget.print_()'''
    def setVisible(self, visible):
        '''void QPrintPreviewWidget.setVisible(bool visible)'''
    def currentPage(self):
        '''int QPrintPreviewWidget.currentPage()'''
        return int()
    def zoomMode(self):
        '''QPrintPreviewWidget.ZoomMode QPrintPreviewWidget.zoomMode()'''
        return QPrintPreviewWidget.ZoomMode()
    def viewMode(self):
        '''QPrintPreviewWidget.ViewMode QPrintPreviewWidget.viewMode()'''
        return QPrintPreviewWidget.ViewMode()
    def orientation(self):
        '''QPrinter.Orientation QPrintPreviewWidget.orientation()'''
        return QPrinter.Orientation()
    def zoomFactor(self):
        '''float QPrintPreviewWidget.zoomFactor()'''
        return float()





# This file is used to unit-test the "correction files" feature,
# and can serve as an example of the capabilities of this feature.

def function_global_func():
    returns = int()

class class_some_class():
    def function___init__(self):
        l_bar = float()

    def function_member_func1(self):
        l_baz = [3]

    def function_member_func2(self):
        returns = [float()]



class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class Phonon():
    """"""
    # Enum Phonon.ErrorType
    NoError = 0
    NormalError = 0
    FatalError = 0

    # Enum Phonon.Category
    NoCategory = 0
    NotificationCategory = 0
    MusicCategory = 0
    VideoCategory = 0
    CommunicationCategory = 0
    GameCategory = 0
    AccessibilityCategory = 0

    # Enum Phonon.State
    LoadingState = 0
    StoppedState = 0
    PlayingState = 0
    BufferingState = 0
    PausedState = 0
    ErrorState = 0

    # Enum Phonon.MetaData
    ArtistMetaData = 0
    AlbumMetaData = 0
    TitleMetaData = 0
    DateMetaData = 0
    GenreMetaData = 0
    TracknumberMetaData = 0
    DescriptionMetaData = 0
    MusicBrainzDiscIdMetaData = 0

    # Enum Phonon.DiscType
    NoDisc = 0
    Cd = 0
    Dvd = 0
    Vcd = 0

    def phononVersion(self):
        '''static str Phonon.phononVersion()'''
        return str()
    def categoryToString(self, c):
        '''static QString Phonon.categoryToString(Phonon.Category c)'''
        return QString()
    def createPath(self, source, sink):
        '''static Phonon.Path Phonon.createPath(Phonon.MediaNode source, Phonon.MediaNode sink)'''
        return Phonon.Path()
    def createPlayer(self, category, source = None):
        '''static Phonon.MediaObject Phonon.createPlayer(Phonon.Category category, Phonon.MediaSource source = Phonon.MediaSource())'''
        return Phonon.MediaObject()
    class Effect(QObject, Phonon.MediaNode):
        """"""
        def __init__(self, description, parent = None):
            '''void Phonon.Effect.__init__(Phonon.EffectDescription description, QObject parent = None)'''
        def setParameterValue(self, value):
            '''Phonon.EffectParameter Phonon.Effect.setParameterValue(QVariant value)'''
            return Phonon.EffectParameter()
        def parameterValue(self):
            '''Phonon.EffectParameter Phonon.Effect.parameterValue()'''
            return Phonon.EffectParameter()
        def parameters(self):
            '''list-of-Phonon.EffectParameter Phonon.Effect.parameters()'''
            return [Phonon.EffectParameter()]
        def description(self):
            '''Phonon.EffectDescription Phonon.Effect.description()'''
            return Phonon.EffectDescription()
    class BackendCapabilities():
        """"""
        def availableAudioCaptureDevices(self):
            '''static list-of-Phonon.AudioCaptureDevice Phonon.BackendCapabilities.availableAudioCaptureDevices()'''
            return [Phonon.AudioCaptureDevice()]
        def availableAudioEffects(self):
            '''static list-of-Phonon.EffectDescription Phonon.BackendCapabilities.availableAudioEffects()'''
            return [Phonon.EffectDescription()]
        def availableAudioOutputDevices(self):
            '''static list-of-Phonon.AudioOutputDevice Phonon.BackendCapabilities.availableAudioOutputDevices()'''
            return [Phonon.AudioOutputDevice()]
        def isMimeTypeAvailable(self, mimeType):
            '''static bool Phonon.BackendCapabilities.isMimeTypeAvailable(QString mimeType)'''
            return bool()
        def availableMimeTypes(self):
            '''static QStringList Phonon.BackendCapabilities.availableMimeTypes()'''
            return QStringList()
        def notifier(self):
            '''static Phonon.BackendCapabilities.Notifier Phonon.BackendCapabilities.notifier()'''
            return Phonon.BackendCapabilities.Notifier()
    class VolumeSlider(QWidget):
        """"""
        def __init__(self, parent = None):
            '''void Phonon.VolumeSlider.__init__(QWidget parent = None)'''
        def __init__(self, parent = None):
            '''Phonon.AudioOutput Phonon.VolumeSlider.__init__(QWidget parent = None)'''
            return Phonon.AudioOutput()
        def setAudioOutput(self):
            '''Phonon.AudioOutput Phonon.VolumeSlider.setAudioOutput()'''
            return Phonon.AudioOutput()
        def setIconSize(self, size):
            '''void Phonon.VolumeSlider.setIconSize(QSize size)'''
        def setMuteVisible(self):
            '''bool Phonon.VolumeSlider.setMuteVisible()'''
            return bool()
        def setOrientation(self):
            '''Qt.Orientation Phonon.VolumeSlider.setOrientation()'''
            return Qt.Orientation()
        def setMaximumVolume(self):
            '''float Phonon.VolumeSlider.setMaximumVolume()'''
            return float()
        def audioOutput(self):
            '''Phonon.AudioOutput Phonon.VolumeSlider.audioOutput()'''
            return Phonon.AudioOutput()
        def orientation(self):
            '''Qt.Orientation Phonon.VolumeSlider.orientation()'''
            return Qt.Orientation()
        def maximumVolume(self):
            '''float Phonon.VolumeSlider.maximumVolume()'''
            return float()
        def iconSize(self):
            '''QSize Phonon.VolumeSlider.iconSize()'''
            return QSize()
        def isMuteVisible(self):
            '''bool Phonon.VolumeSlider.isMuteVisible()'''
            return bool()
        def setSingleStep(self, milliseconds):
            '''void Phonon.VolumeSlider.setSingleStep(int milliseconds)'''
        def singleStep(self):
            '''int Phonon.VolumeSlider.singleStep()'''
            return int()
        def setPageStep(self, milliseconds):
            '''void Phonon.VolumeSlider.setPageStep(int milliseconds)'''
        def pageStep(self):
            '''int Phonon.VolumeSlider.pageStep()'''
            return int()
        def setTracking(self, tracking):
            '''void Phonon.VolumeSlider.setTracking(bool tracking)'''
        def hasTracking(self):
            '''bool Phonon.VolumeSlider.hasTracking()'''
            return bool()
    class VideoPlayer(QWidget):
        """"""
        def __init__(self, category, parent = None):
            '''void Phonon.VideoPlayer.__init__(Phonon.Category category, QWidget parent = None)'''
        def __init__(self, parent = None):
            '''void Phonon.VideoPlayer.__init__(QWidget parent = None)'''
        finished = pyqtSignal() # void finished() - signal
        def videoWidget(self):
            '''Phonon.VideoWidget Phonon.VideoPlayer.videoWidget()'''
            return Phonon.VideoWidget()
        def audioOutput(self):
            '''Phonon.AudioOutput Phonon.VideoPlayer.audioOutput()'''
            return Phonon.AudioOutput()
        def mediaObject(self):
            '''Phonon.MediaObject Phonon.VideoPlayer.mediaObject()'''
            return Phonon.MediaObject()
        def setVolume(self, volume):
            '''void Phonon.VideoPlayer.setVolume(float volume)'''
        def seek(self, ms):
            '''void Phonon.VideoPlayer.seek(int ms)'''
        def stop(self):
            '''void Phonon.VideoPlayer.stop()'''
        def pause(self):
            '''void Phonon.VideoPlayer.pause()'''
        def play(self, source):
            '''void Phonon.VideoPlayer.play(Phonon.MediaSource source)'''
        def play(self):
            '''void Phonon.VideoPlayer.play()'''
        def load(self, source):
            '''void Phonon.VideoPlayer.load(Phonon.MediaSource source)'''
        def isPaused(self):
            '''bool Phonon.VideoPlayer.isPaused()'''
            return bool()
        def isPlaying(self):
            '''bool Phonon.VideoPlayer.isPlaying()'''
            return bool()
        def volume(self):
            '''float Phonon.VideoPlayer.volume()'''
            return float()
        def currentTime(self):
            '''int Phonon.VideoPlayer.currentTime()'''
            return int()
        def totalTime(self):
            '''int Phonon.VideoPlayer.totalTime()'''
            return int()
    class AbstractVideoOutput(Phonon.MediaNode):
        """"""
    class VideoWidget(QWidget, Phonon.AbstractVideoOutput):
        """"""
        # Enum Phonon.VideoWidget.ScaleMode
        FitInView = 0
        ScaleAndCrop = 0
    
        # Enum Phonon.VideoWidget.AspectRatio
        AspectRatioAuto = 0
        AspectRatioWidget = 0
        AspectRatio4_3 = 0
        AspectRatio16_9 = 0
    
        def __init__(self, parent = None):
            '''void Phonon.VideoWidget.__init__(QWidget parent = None)'''
        def snapshot(self):
            '''QImage Phonon.VideoWidget.snapshot()'''
            return QImage()
        def event(self):
            '''QEvent Phonon.VideoWidget.event()'''
            return QEvent()
        def mouseMoveEvent(self):
            '''QMouseEvent Phonon.VideoWidget.mouseMoveEvent()'''
            return QMouseEvent()
        def setSaturation(self, value):
            '''void Phonon.VideoWidget.setSaturation(float value)'''
        def setHue(self, value):
            '''void Phonon.VideoWidget.setHue(float value)'''
        def setContrast(self, value):
            '''void Phonon.VideoWidget.setContrast(float value)'''
        def setBrightness(self, value):
            '''void Phonon.VideoWidget.setBrightness(float value)'''
        def setScaleMode(self):
            '''Phonon.VideoWidget.ScaleMode Phonon.VideoWidget.setScaleMode()'''
            return Phonon.VideoWidget.ScaleMode()
        def setAspectRatio(self):
            '''Phonon.VideoWidget.AspectRatio Phonon.VideoWidget.setAspectRatio()'''
            return Phonon.VideoWidget.AspectRatio()
        def enterFullScreen(self):
            '''void Phonon.VideoWidget.enterFullScreen()'''
        def exitFullScreen(self):
            '''void Phonon.VideoWidget.exitFullScreen()'''
        def setFullScreen(self, fullscreen):
            '''void Phonon.VideoWidget.setFullScreen(bool fullscreen)'''
        def saturation(self):
            '''float Phonon.VideoWidget.saturation()'''
            return float()
        def hue(self):
            '''float Phonon.VideoWidget.hue()'''
            return float()
        def contrast(self):
            '''float Phonon.VideoWidget.contrast()'''
            return float()
        def brightness(self):
            '''float Phonon.VideoWidget.brightness()'''
            return float()
        def scaleMode(self):
            '''Phonon.VideoWidget.ScaleMode Phonon.VideoWidget.scaleMode()'''
            return Phonon.VideoWidget.ScaleMode()
        def aspectRatio(self):
            '''Phonon.VideoWidget.AspectRatio Phonon.VideoWidget.aspectRatio()'''
            return Phonon.VideoWidget.AspectRatio()
    class Path():
        """"""
        def __init__(self):
            '''void Phonon.Path.__init__()'''
        def __init__(self):
            '''Phonon.Path Phonon.Path.__init__()'''
            return Phonon.Path()
        def sink(self):
            '''Phonon.MediaNode Phonon.Path.sink()'''
            return Phonon.MediaNode()
        def source(self):
            '''Phonon.MediaNode Phonon.Path.source()'''
            return Phonon.MediaNode()
        def __ne__(self, p):
            '''bool Phonon.Path.__ne__(Phonon.Path p)'''
            return bool()
        def __eq__(self, p):
            '''bool Phonon.Path.__eq__(Phonon.Path p)'''
            return bool()
        def disconnect(self):
            '''bool Phonon.Path.disconnect()'''
            return bool()
        def reconnect(self, source, sink):
            '''bool Phonon.Path.reconnect(Phonon.MediaNode source, Phonon.MediaNode sink)'''
            return bool()
        def effects(self):
            '''list-of-Phonon.Effect Phonon.Path.effects()'''
            return [Phonon.Effect()]
        def removeEffect(self, effect):
            '''bool Phonon.Path.removeEffect(Phonon.Effect effect)'''
            return bool()
        def insertEffect(self, desc, before = None):
            '''Phonon.Effect Phonon.Path.insertEffect(Phonon.EffectDescription desc, Phonon.Effect before = None)'''
            return Phonon.Effect()
        def insertEffect(self, newEffect, before = None):
            '''bool Phonon.Path.insertEffect(Phonon.Effect newEffect, Phonon.Effect before = None)'''
            return bool()
        def isValid(self):
            '''bool Phonon.Path.isValid()'''
            return bool()
    class EffectParameter():
        """"""
        # Enum Phonon.EffectParameter.Hint
        ToggledHint = 0
        LogarithmicHint = 0
        IntegerHint = 0
    
        def __init__(self, parameterId, name, hints, defaultValue, min = QVariant(), max = QVariant(), values = None, description = QString()):
            '''void Phonon.EffectParameter.__init__(int parameterId, QString name, Phonon.EffectParameter.Hints hints, QVariant defaultValue, QVariant min = QVariant(), QVariant max = QVariant(), list-of-QVariant values = [], QString description = QString())'''
        def __init__(self, rhs):
            '''void Phonon.EffectParameter.__init__(Phonon.EffectParameter rhs)'''
        def __hash__(self):
            '''int Phonon.EffectParameter.__hash__()'''
            return int()
        def possibleValues(self):
            '''list-of-QVariant Phonon.EffectParameter.possibleValues()'''
            return [QVariant()]
        def defaultValue(self):
            '''QVariant Phonon.EffectParameter.defaultValue()'''
            return QVariant()
        def maximumValue(self):
            '''QVariant Phonon.EffectParameter.maximumValue()'''
            return QVariant()
        def minimumValue(self):
            '''QVariant Phonon.EffectParameter.minimumValue()'''
            return QVariant()
        def isLogarithmicControl(self):
            '''bool Phonon.EffectParameter.isLogarithmicControl()'''
            return bool()
        def type(self):
            '''Type Phonon.EffectParameter.type()'''
            return Type()
        def description(self):
            '''QString Phonon.EffectParameter.description()'''
            return QString()
        def name(self):
            '''QString Phonon.EffectParameter.name()'''
            return QString()
    class AudioCaptureDevice():
        """"""
        def __init__(self):
            '''void Phonon.AudioCaptureDevice.__init__()'''
        def __init__(self, index, properties):
            '''void Phonon.AudioCaptureDevice.__init__(int index, dict-of-QByteArray-QVariant properties)'''
        def __init__(self):
            '''Phonon.AudioCaptureDevice Phonon.AudioCaptureDevice.__init__()'''
            return Phonon.AudioCaptureDevice()
        def fromIndex(self, index):
            '''static Phonon.AudioCaptureDevice Phonon.AudioCaptureDevice.fromIndex(int index)'''
            return Phonon.AudioCaptureDevice()
        def __eq__(self, otherDescription):
            '''bool Phonon.AudioCaptureDevice.__eq__(Phonon.AudioCaptureDevice otherDescription)'''
            return bool()
        def __ne__(self, otherDescription):
            '''bool Phonon.AudioCaptureDevice.__ne__(Phonon.AudioCaptureDevice otherDescription)'''
            return bool()
        def propertyNames(self):
            '''list-of-QByteArray Phonon.AudioCaptureDevice.propertyNames()'''
            return [QByteArray()]
        def property(self, name):
            '''QVariant Phonon.AudioCaptureDevice.property(str name)'''
            return QVariant()
        def name(self):
            '''QString Phonon.AudioCaptureDevice.name()'''
            return QString()
        def isValid(self):
            '''bool Phonon.AudioCaptureDevice.isValid()'''
            return bool()
        def index(self):
            '''int Phonon.AudioCaptureDevice.index()'''
            return int()
        def description(self):
            '''QString Phonon.AudioCaptureDevice.description()'''
            return QString()
    class EffectWidget(QWidget):
        """"""
        def __init__(self, effect, parent = None):
            '''void Phonon.EffectWidget.__init__(Phonon.Effect effect, QWidget parent = None)'''
    class AudioOutput(Phonon.AbstractAudioOutput):
        """"""
        def __init__(self, category, parent = None):
            '''void Phonon.AudioOutput.__init__(Phonon.Category category, QObject parent = None)'''
        def __init__(self, parent = None):
            '''void Phonon.AudioOutput.__init__(QObject parent = None)'''
        outputDeviceChanged = pyqtSignal() # void outputDeviceChanged(const Phonon::AudioOutputDeviceamp;) - signal
        mutedChanged = pyqtSignal() # void mutedChanged(bool) - signal
        volumeChanged = pyqtSignal() # void volumeChanged(qreal) - signal
        def setMuted(self, mute):
            '''void Phonon.AudioOutput.setMuted(bool mute)'''
        def setOutputDevice(self, newAudioOutputDevice):
            '''bool Phonon.AudioOutput.setOutputDevice(Phonon.AudioOutputDevice newAudioOutputDevice)'''
            return bool()
        def setVolumeDecibel(self, newVolumeDecibel):
            '''void Phonon.AudioOutput.setVolumeDecibel(float newVolumeDecibel)'''
        def setVolume(self, newVolume):
            '''void Phonon.AudioOutput.setVolume(float newVolume)'''
        def setName(self, newName):
            '''void Phonon.AudioOutput.setName(QString newName)'''
        def isMuted(self):
            '''bool Phonon.AudioOutput.isMuted()'''
            return bool()
        def outputDevice(self):
            '''Phonon.AudioOutputDevice Phonon.AudioOutput.outputDevice()'''
            return Phonon.AudioOutputDevice()
        def category(self):
            '''Phonon.Category Phonon.AudioOutput.category()'''
            return Phonon.Category()
        def volumeDecibel(self):
            '''float Phonon.AudioOutput.volumeDecibel()'''
            return float()
        def volume(self):
            '''float Phonon.AudioOutput.volume()'''
            return float()
        def name(self):
            '''QString Phonon.AudioOutput.name()'''
            return QString()
    class MediaNode():
        """"""
        def outputPaths(self):
            '''list-of-Phonon.Path Phonon.MediaNode.outputPaths()'''
            return [Phonon.Path()]
        def inputPaths(self):
            '''list-of-Phonon.Path Phonon.MediaNode.inputPaths()'''
            return [Phonon.Path()]
        def isValid(self):
            '''bool Phonon.MediaNode.isValid()'''
            return bool()
    class SeekSlider(QWidget):
        """"""
        def __init__(self, parent = None):
            '''void Phonon.SeekSlider.__init__(QWidget parent = None)'''
        def __init__(self, media, parent = None):
            '''void Phonon.SeekSlider.__init__(Phonon.MediaObject media, QWidget parent = None)'''
        def setMediaObject(self):
            '''Phonon.MediaObject Phonon.SeekSlider.setMediaObject()'''
            return Phonon.MediaObject()
        def setIconSize(self, size):
            '''void Phonon.SeekSlider.setIconSize(QSize size)'''
        def setIconVisible(self):
            '''bool Phonon.SeekSlider.setIconVisible()'''
            return bool()
        def setOrientation(self):
            '''Qt.Orientation Phonon.SeekSlider.setOrientation()'''
            return Qt.Orientation()
        def mediaObject(self):
            '''Phonon.MediaObject Phonon.SeekSlider.mediaObject()'''
            return Phonon.MediaObject()
        def iconSize(self):
            '''QSize Phonon.SeekSlider.iconSize()'''
            return QSize()
        def isIconVisible(self):
            '''bool Phonon.SeekSlider.isIconVisible()'''
            return bool()
        def orientation(self):
            '''Qt.Orientation Phonon.SeekSlider.orientation()'''
            return Qt.Orientation()
        def setSingleStep(self, milliseconds):
            '''void Phonon.SeekSlider.setSingleStep(int milliseconds)'''
        def singleStep(self):
            '''int Phonon.SeekSlider.singleStep()'''
            return int()
        def setPageStep(self, milliseconds):
            '''void Phonon.SeekSlider.setPageStep(int milliseconds)'''
        def pageStep(self):
            '''int Phonon.SeekSlider.pageStep()'''
            return int()
        def setTracking(self, tracking):
            '''void Phonon.SeekSlider.setTracking(bool tracking)'''
        def hasTracking(self):
            '''bool Phonon.SeekSlider.hasTracking()'''
            return bool()
    class EffectParameter():
        """"""
        class Hints():
            """"""
            def __init__(self):
                '''Phonon.EffectParameter.Hints Phonon.EffectParameter.Hints.__init__()'''
                return Phonon.EffectParameter.Hints()
            def __init__(self):
                '''int Phonon.EffectParameter.Hints.__init__()'''
                return int()
            def __init__(self):
                '''void Phonon.EffectParameter.Hints.__init__()'''
            def __bool__(self):
                '''int Phonon.EffectParameter.Hints.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool Phonon.EffectParameter.Hints.__ne__(Phonon.EffectParameter.Hints f)'''
                return bool()
            def __eq__(self, f):
                '''bool Phonon.EffectParameter.Hints.__eq__(Phonon.EffectParameter.Hints f)'''
                return bool()
            def __invert__(self):
                '''Phonon.EffectParameter.Hints Phonon.EffectParameter.Hints.__invert__()'''
                return Phonon.EffectParameter.Hints()
            def __and__(self, mask):
                '''Phonon.EffectParameter.Hints Phonon.EffectParameter.Hints.__and__(int mask)'''
                return Phonon.EffectParameter.Hints()
            def __xor__(self, f):
                '''Phonon.EffectParameter.Hints Phonon.EffectParameter.Hints.__xor__(Phonon.EffectParameter.Hints f)'''
                return Phonon.EffectParameter.Hints()
            def __xor__(self, f):
                '''Phonon.EffectParameter.Hints Phonon.EffectParameter.Hints.__xor__(int f)'''
                return Phonon.EffectParameter.Hints()
            def __or__(self, f):
                '''Phonon.EffectParameter.Hints Phonon.EffectParameter.Hints.__or__(Phonon.EffectParameter.Hints f)'''
                return Phonon.EffectParameter.Hints()
            def __or__(self, f):
                '''Phonon.EffectParameter.Hints Phonon.EffectParameter.Hints.__or__(int f)'''
                return Phonon.EffectParameter.Hints()
            def __int__(self):
                '''int Phonon.EffectParameter.Hints.__int__()'''
                return int()
            def __ixor__(self, f):
                '''Phonon.EffectParameter.Hints Phonon.EffectParameter.Hints.__ixor__(Phonon.EffectParameter.Hints f)'''
                return Phonon.EffectParameter.Hints()
            def __ior__(self, f):
                '''Phonon.EffectParameter.Hints Phonon.EffectParameter.Hints.__ior__(Phonon.EffectParameter.Hints f)'''
                return Phonon.EffectParameter.Hints()
            def __iand__(self, mask):
                '''Phonon.EffectParameter.Hints Phonon.EffectParameter.Hints.__iand__(int mask)'''
                return Phonon.EffectParameter.Hints()
    class BackendCapabilities():
        """"""
        class Notifier(QObject):
            """"""
            availableAudioCaptureDevicesChanged = pyqtSignal() # void availableAudioCaptureDevicesChanged() - signal
            availableAudioOutputDevicesChanged = pyqtSignal() # void availableAudioOutputDevicesChanged() - signal
            capabilitiesChanged = pyqtSignal() # void capabilitiesChanged() - signal
    class MediaController(QObject):
        """"""
        # Enum Phonon.MediaController.Feature
        Angles = 0
        Chapters = 0
        Titles = 0
    
        def __init__(self, parent):
            '''void Phonon.MediaController.__init__(Phonon.MediaObject parent)'''
        availableAudioChannelsChanged = pyqtSignal() # void availableAudioChannelsChanged() - signal
        availableSubtitlesChanged = pyqtSignal() # void availableSubtitlesChanged() - signal
        def setCurrentSubtitle(self, stream):
            '''void Phonon.MediaController.setCurrentSubtitle(Phonon.SubtitleDescription stream)'''
        def setCurrentAudioChannel(self, stream):
            '''void Phonon.MediaController.setCurrentAudioChannel(Phonon.AudioChannelDescription stream)'''
        def availableSubtitles(self):
            '''list-of-Phonon.SubtitleDescription Phonon.MediaController.availableSubtitles()'''
            return [Phonon.SubtitleDescription()]
        def availableAudioChannels(self):
            '''list-of-Phonon.AudioChannelDescription Phonon.MediaController.availableAudioChannels()'''
            return [Phonon.AudioChannelDescription()]
        def currentSubtitle(self):
            '''Phonon.SubtitleDescription Phonon.MediaController.currentSubtitle()'''
            return Phonon.SubtitleDescription()
        def currentAudioChannel(self):
            '''Phonon.AudioChannelDescription Phonon.MediaController.currentAudioChannel()'''
            return Phonon.AudioChannelDescription()
        titleChanged = pyqtSignal() # void titleChanged(int) - signal
        availableTitlesChanged = pyqtSignal() # void availableTitlesChanged(int) - signal
        chapterChanged = pyqtSignal() # void chapterChanged(int) - signal
        availableChaptersChanged = pyqtSignal() # void availableChaptersChanged(int) - signal
        angleChanged = pyqtSignal() # void angleChanged(int) - signal
        availableAnglesChanged = pyqtSignal() # void availableAnglesChanged(int) - signal
        def previousTitle(self):
            '''void Phonon.MediaController.previousTitle()'''
        def nextTitle(self):
            '''void Phonon.MediaController.nextTitle()'''
        def setAutoplayTitles(self):
            '''bool Phonon.MediaController.setAutoplayTitles()'''
            return bool()
        def setCurrentTitle(self, titleNumber):
            '''void Phonon.MediaController.setCurrentTitle(int titleNumber)'''
        def setCurrentChapter(self, chapterNumber):
            '''void Phonon.MediaController.setCurrentChapter(int chapterNumber)'''
        def setCurrentAngle(self, angleNumber):
            '''void Phonon.MediaController.setCurrentAngle(int angleNumber)'''
        def autoplayTitles(self):
            '''bool Phonon.MediaController.autoplayTitles()'''
            return bool()
        def currentTitle(self):
            '''int Phonon.MediaController.currentTitle()'''
            return int()
        def availableTitles(self):
            '''int Phonon.MediaController.availableTitles()'''
            return int()
        def currentChapter(self):
            '''int Phonon.MediaController.currentChapter()'''
            return int()
        def availableChapters(self):
            '''int Phonon.MediaController.availableChapters()'''
            return int()
        def currentAngle(self):
            '''int Phonon.MediaController.currentAngle()'''
            return int()
        def availableAngles(self):
            '''int Phonon.MediaController.availableAngles()'''
            return int()
        def supportedFeatures(self):
            '''Phonon.MediaController.Features Phonon.MediaController.supportedFeatures()'''
            return Phonon.MediaController.Features()
    class MediaSource():
        """"""
        # Enum Phonon.MediaSource.Type
        Invalid = 0
        LocalFile = 0
        Url = 0
        Disc = 0
        Stream = 0
        Empty = 0
    
        def __init__(self, fileName):
            '''void Phonon.MediaSource.__init__(QString fileName)'''
        def __init__(self, url):
            '''void Phonon.MediaSource.__init__(QUrl url)'''
        def __init__(self, discType, deviceName = QString()):
            '''void Phonon.MediaSource.__init__(Phonon.DiscType discType, QString deviceName = QString())'''
        def __init__(self, ioDevice):
            '''void Phonon.MediaSource.__init__(QIODevice ioDevice)'''
        def __init__(self, rhs):
            '''void Phonon.MediaSource.__init__(Phonon.MediaSource rhs)'''
        def __ne__(self, rhs):
            '''bool Phonon.MediaSource.__ne__(Phonon.MediaSource rhs)'''
            return bool()
        def deviceName(self):
            '''QString Phonon.MediaSource.deviceName()'''
            return QString()
        def discType(self):
            '''Phonon.DiscType Phonon.MediaSource.discType()'''
            return Phonon.DiscType()
        def url(self):
            '''QUrl Phonon.MediaSource.url()'''
            return QUrl()
        def fileName(self):
            '''QString Phonon.MediaSource.fileName()'''
            return QString()
        def type(self):
            '''Phonon.MediaSource.Type Phonon.MediaSource.type()'''
            return Phonon.MediaSource.Type()
        def autoDelete(self):
            '''bool Phonon.MediaSource.autoDelete()'''
            return bool()
        def setAutoDelete(self, enable):
            '''void Phonon.MediaSource.setAutoDelete(bool enable)'''
        def __eq__(self, rhs):
            '''bool Phonon.MediaSource.__eq__(Phonon.MediaSource rhs)'''
            return bool()
    class AudioOutputDevice():
        """"""
        def __init__(self):
            '''void Phonon.AudioOutputDevice.__init__()'''
        def __init__(self, index, properties):
            '''void Phonon.AudioOutputDevice.__init__(int index, dict-of-QByteArray-QVariant properties)'''
        def __init__(self):
            '''Phonon.AudioOutputDevice Phonon.AudioOutputDevice.__init__()'''
            return Phonon.AudioOutputDevice()
        def fromIndex(self, index):
            '''static Phonon.AudioOutputDevice Phonon.AudioOutputDevice.fromIndex(int index)'''
            return Phonon.AudioOutputDevice()
        def __eq__(self, otherDescription):
            '''bool Phonon.AudioOutputDevice.__eq__(Phonon.AudioOutputDevice otherDescription)'''
            return bool()
        def __ne__(self, otherDescription):
            '''bool Phonon.AudioOutputDevice.__ne__(Phonon.AudioOutputDevice otherDescription)'''
            return bool()
        def propertyNames(self):
            '''list-of-QByteArray Phonon.AudioOutputDevice.propertyNames()'''
            return [QByteArray()]
        def property(self, name):
            '''QVariant Phonon.AudioOutputDevice.property(str name)'''
            return QVariant()
        def name(self):
            '''QString Phonon.AudioOutputDevice.name()'''
            return QString()
        def isValid(self):
            '''bool Phonon.AudioOutputDevice.isValid()'''
            return bool()
        def index(self):
            '''int Phonon.AudioOutputDevice.index()'''
            return int()
        def description(self):
            '''QString Phonon.AudioOutputDevice.description()'''
            return QString()
    class AudioOutputDeviceModel(QAbstractListModel):
        """"""
        def __init__(self, parent = None):
            '''void Phonon.AudioOutputDeviceModel.__init__(QObject parent = None)'''
        def __init__(self, data, parent = None):
            '''void Phonon.AudioOutputDeviceModel.__init__(list-of-Phonon.AudioOutputDevice data, QObject parent = None)'''
        def mimeTypes(self):
            '''QStringList Phonon.AudioOutputDeviceModel.mimeTypes()'''
            return QStringList()
        def removeRows(self, row, count, parent = QModelIndex()):
            '''bool Phonon.AudioOutputDeviceModel.removeRows(int row, int count, QModelIndex parent = QModelIndex())'''
            return bool()
        def dropMimeData(self, data, action, row, column, parent):
            '''bool Phonon.AudioOutputDeviceModel.dropMimeData(QMimeData data, Qt.DropAction action, int row, int column, QModelIndex parent)'''
            return bool()
        def supportedDropActions(self):
            '''Qt.DropActions Phonon.AudioOutputDeviceModel.supportedDropActions()'''
            return Qt.DropActions()
        def mimeData(self, indexes):
            '''QMimeData Phonon.AudioOutputDeviceModel.mimeData(list-of-QModelIndex indexes)'''
            return QMimeData()
        def flags(self, index):
            '''Qt.ItemFlags Phonon.AudioOutputDeviceModel.flags(QModelIndex index)'''
            return Qt.ItemFlags()
        def data(self, index, role = None):
            '''QVariant Phonon.AudioOutputDeviceModel.data(QModelIndex index, int role = Qt.DisplayRole)'''
            return QVariant()
        def rowCount(self, parent = QModelIndex()):
            '''int Phonon.AudioOutputDeviceModel.rowCount(QModelIndex parent = QModelIndex())'''
            return int()
        def modelData(self):
            '''list-of-Phonon.AudioOutputDevice Phonon.AudioOutputDeviceModel.modelData()'''
            return [Phonon.AudioOutputDevice()]
        def modelData(self, index):
            '''Phonon.AudioOutputDevice Phonon.AudioOutputDeviceModel.modelData(QModelIndex index)'''
            return Phonon.AudioOutputDevice()
        def setModelData(self, data):
            '''void Phonon.AudioOutputDeviceModel.setModelData(list-of-Phonon.AudioOutputDevice data)'''
        def moveDown(self, index):
            '''void Phonon.AudioOutputDeviceModel.moveDown(QModelIndex index)'''
        def moveUp(self, index):
            '''void Phonon.AudioOutputDeviceModel.moveUp(QModelIndex index)'''
        def tupleIndexAtPositionIndex(self, positionIndex):
            '''int Phonon.AudioOutputDeviceModel.tupleIndexAtPositionIndex(int positionIndex)'''
            return int()
        def tupleIndexOrder(self):
            '''list-of-int Phonon.AudioOutputDeviceModel.tupleIndexOrder()'''
            return [int()]
    class EffectDescriptionModel(QAbstractListModel):
        """"""
        def __init__(self, parent = None):
            '''void Phonon.EffectDescriptionModel.__init__(QObject parent = None)'''
        def __init__(self, data, parent = None):
            '''void Phonon.EffectDescriptionModel.__init__(list-of-Phonon.EffectDescription data, QObject parent = None)'''
        def mimeTypes(self):
            '''QStringList Phonon.EffectDescriptionModel.mimeTypes()'''
            return QStringList()
        def removeRows(self, row, count, parent = QModelIndex()):
            '''bool Phonon.EffectDescriptionModel.removeRows(int row, int count, QModelIndex parent = QModelIndex())'''
            return bool()
        def dropMimeData(self, data, action, row, column, parent):
            '''bool Phonon.EffectDescriptionModel.dropMimeData(QMimeData data, Qt.DropAction action, int row, int column, QModelIndex parent)'''
            return bool()
        def supportedDropActions(self):
            '''Qt.DropActions Phonon.EffectDescriptionModel.supportedDropActions()'''
            return Qt.DropActions()
        def mimeData(self, indexes):
            '''QMimeData Phonon.EffectDescriptionModel.mimeData(list-of-QModelIndex indexes)'''
            return QMimeData()
        def flags(self, index):
            '''Qt.ItemFlags Phonon.EffectDescriptionModel.flags(QModelIndex index)'''
            return Qt.ItemFlags()
        def data(self, index, role = None):
            '''QVariant Phonon.EffectDescriptionModel.data(QModelIndex index, int role = Qt.DisplayRole)'''
            return QVariant()
        def rowCount(self, parent = QModelIndex()):
            '''int Phonon.EffectDescriptionModel.rowCount(QModelIndex parent = QModelIndex())'''
            return int()
        def modelData(self):
            '''list-of-Phonon.EffectDescription Phonon.EffectDescriptionModel.modelData()'''
            return [Phonon.EffectDescription()]
        def modelData(self, index):
            '''Phonon.EffectDescription Phonon.EffectDescriptionModel.modelData(QModelIndex index)'''
            return Phonon.EffectDescription()
        def setModelData(self, data):
            '''void Phonon.EffectDescriptionModel.setModelData(list-of-Phonon.EffectDescription data)'''
        def moveDown(self, index):
            '''void Phonon.EffectDescriptionModel.moveDown(QModelIndex index)'''
        def moveUp(self, index):
            '''void Phonon.EffectDescriptionModel.moveUp(QModelIndex index)'''
        def tupleIndexAtPositionIndex(self, positionIndex):
            '''int Phonon.EffectDescriptionModel.tupleIndexAtPositionIndex(int positionIndex)'''
            return int()
        def tupleIndexOrder(self):
            '''list-of-int Phonon.EffectDescriptionModel.tupleIndexOrder()'''
            return [int()]
    class MediaController():
        """"""
        class Features():
            """"""
            def __init__(self):
                '''Phonon.MediaController.Features Phonon.MediaController.Features.__init__()'''
                return Phonon.MediaController.Features()
            def __init__(self):
                '''int Phonon.MediaController.Features.__init__()'''
                return int()
            def __init__(self):
                '''void Phonon.MediaController.Features.__init__()'''
            def __bool__(self):
                '''int Phonon.MediaController.Features.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool Phonon.MediaController.Features.__ne__(Phonon.MediaController.Features f)'''
                return bool()
            def __eq__(self, f):
                '''bool Phonon.MediaController.Features.__eq__(Phonon.MediaController.Features f)'''
                return bool()
            def __invert__(self):
                '''Phonon.MediaController.Features Phonon.MediaController.Features.__invert__()'''
                return Phonon.MediaController.Features()
            def __and__(self, mask):
                '''Phonon.MediaController.Features Phonon.MediaController.Features.__and__(int mask)'''
                return Phonon.MediaController.Features()
            def __xor__(self, f):
                '''Phonon.MediaController.Features Phonon.MediaController.Features.__xor__(Phonon.MediaController.Features f)'''
                return Phonon.MediaController.Features()
            def __xor__(self, f):
                '''Phonon.MediaController.Features Phonon.MediaController.Features.__xor__(int f)'''
                return Phonon.MediaController.Features()
            def __or__(self, f):
                '''Phonon.MediaController.Features Phonon.MediaController.Features.__or__(Phonon.MediaController.Features f)'''
                return Phonon.MediaController.Features()
            def __or__(self, f):
                '''Phonon.MediaController.Features Phonon.MediaController.Features.__or__(int f)'''
                return Phonon.MediaController.Features()
            def __int__(self):
                '''int Phonon.MediaController.Features.__int__()'''
                return int()
            def __ixor__(self, f):
                '''Phonon.MediaController.Features Phonon.MediaController.Features.__ixor__(Phonon.MediaController.Features f)'''
                return Phonon.MediaController.Features()
            def __ior__(self, f):
                '''Phonon.MediaController.Features Phonon.MediaController.Features.__ior__(Phonon.MediaController.Features f)'''
                return Phonon.MediaController.Features()
            def __iand__(self, mask):
                '''Phonon.MediaController.Features Phonon.MediaController.Features.__iand__(int mask)'''
                return Phonon.MediaController.Features()
    class AudioChannelDescription():
        """"""
        def __init__(self):
            '''void Phonon.AudioChannelDescription.__init__()'''
        def __init__(self, index, properties):
            '''void Phonon.AudioChannelDescription.__init__(int index, dict-of-QByteArray-QVariant properties)'''
        def __init__(self):
            '''Phonon.AudioChannelDescription Phonon.AudioChannelDescription.__init__()'''
            return Phonon.AudioChannelDescription()
        def fromIndex(self, index):
            '''static Phonon.AudioChannelDescription Phonon.AudioChannelDescription.fromIndex(int index)'''
            return Phonon.AudioChannelDescription()
        def __eq__(self, otherDescription):
            '''bool Phonon.AudioChannelDescription.__eq__(Phonon.AudioChannelDescription otherDescription)'''
            return bool()
        def __ne__(self, otherDescription):
            '''bool Phonon.AudioChannelDescription.__ne__(Phonon.AudioChannelDescription otherDescription)'''
            return bool()
        def propertyNames(self):
            '''list-of-QByteArray Phonon.AudioChannelDescription.propertyNames()'''
            return [QByteArray()]
        def property(self, name):
            '''QVariant Phonon.AudioChannelDescription.property(str name)'''
            return QVariant()
        def name(self):
            '''QString Phonon.AudioChannelDescription.name()'''
            return QString()
        def isValid(self):
            '''bool Phonon.AudioChannelDescription.isValid()'''
            return bool()
        def index(self):
            '''int Phonon.AudioChannelDescription.index()'''
            return int()
        def description(self):
            '''QString Phonon.AudioChannelDescription.description()'''
            return QString()
    class EffectDescription():
        """"""
        def __init__(self):
            '''void Phonon.EffectDescription.__init__()'''
        def __init__(self, index, properties):
            '''void Phonon.EffectDescription.__init__(int index, dict-of-QByteArray-QVariant properties)'''
        def __init__(self):
            '''Phonon.EffectDescription Phonon.EffectDescription.__init__()'''
            return Phonon.EffectDescription()
        def fromIndex(self, index):
            '''static Phonon.EffectDescription Phonon.EffectDescription.fromIndex(int index)'''
            return Phonon.EffectDescription()
        def __eq__(self, otherDescription):
            '''bool Phonon.EffectDescription.__eq__(Phonon.EffectDescription otherDescription)'''
            return bool()
        def __ne__(self, otherDescription):
            '''bool Phonon.EffectDescription.__ne__(Phonon.EffectDescription otherDescription)'''
            return bool()
        def propertyNames(self):
            '''list-of-QByteArray Phonon.EffectDescription.propertyNames()'''
            return [QByteArray()]
        def property(self, name):
            '''QVariant Phonon.EffectDescription.property(str name)'''
            return QVariant()
        def name(self):
            '''QString Phonon.EffectDescription.name()'''
            return QString()
        def isValid(self):
            '''bool Phonon.EffectDescription.isValid()'''
            return bool()
        def index(self):
            '''int Phonon.EffectDescription.index()'''
            return int()
        def description(self):
            '''QString Phonon.EffectDescription.description()'''
            return QString()
    class SubtitleDescription():
        """"""
        def __init__(self):
            '''void Phonon.SubtitleDescription.__init__()'''
        def __init__(self, index, properties):
            '''void Phonon.SubtitleDescription.__init__(int index, dict-of-QByteArray-QVariant properties)'''
        def __init__(self):
            '''Phonon.SubtitleDescription Phonon.SubtitleDescription.__init__()'''
            return Phonon.SubtitleDescription()
        def fromIndex(self, index):
            '''static Phonon.SubtitleDescription Phonon.SubtitleDescription.fromIndex(int index)'''
            return Phonon.SubtitleDescription()
        def __eq__(self, otherDescription):
            '''bool Phonon.SubtitleDescription.__eq__(Phonon.SubtitleDescription otherDescription)'''
            return bool()
        def __ne__(self, otherDescription):
            '''bool Phonon.SubtitleDescription.__ne__(Phonon.SubtitleDescription otherDescription)'''
            return bool()
        def propertyNames(self):
            '''list-of-QByteArray Phonon.SubtitleDescription.propertyNames()'''
            return [QByteArray()]
        def property(self, name):
            '''QVariant Phonon.SubtitleDescription.property(str name)'''
            return QVariant()
        def name(self):
            '''QString Phonon.SubtitleDescription.name()'''
            return QString()
        def isValid(self):
            '''bool Phonon.SubtitleDescription.isValid()'''
            return bool()
        def index(self):
            '''int Phonon.SubtitleDescription.index()'''
            return int()
        def description(self):
            '''QString Phonon.SubtitleDescription.description()'''
            return QString()
    class AbstractAudioOutput(QObject, Phonon.MediaNode):
        """"""
    class MediaObject(QObject, Phonon.MediaNode):
        """"""
        def __init__(self, parent = None):
            '''void Phonon.MediaObject.__init__(QObject parent = None)'''
        totalTimeChanged = pyqtSignal() # void totalTimeChanged(qint64) - signal
        prefinishMarkReached = pyqtSignal() # void prefinishMarkReached(qint32) - signal
        aboutToFinish = pyqtSignal() # void aboutToFinish() - signal
        currentSourceChanged = pyqtSignal() # void currentSourceChanged(const Phonon::MediaSourceamp;) - signal
        finished = pyqtSignal() # void finished() - signal
        bufferStatus = pyqtSignal() # void bufferStatus(int) - signal
        hasVideoChanged = pyqtSignal() # void hasVideoChanged(bool) - signal
        seekableChanged = pyqtSignal() # void seekableChanged(bool) - signal
        metaDataChanged = pyqtSignal() # void metaDataChanged() - signal
        tick = pyqtSignal() # void tick(qint64) - signal
        stateChanged = pyqtSignal() # void stateChanged(Phonon::State,Phonon::State) - signal
        def clear(self):
            '''void Phonon.MediaObject.clear()'''
        def seek(self, time):
            '''void Phonon.MediaObject.seek(int time)'''
        def stop(self):
            '''void Phonon.MediaObject.stop()'''
        def pause(self):
            '''void Phonon.MediaObject.pause()'''
        def play(self):
            '''void Phonon.MediaObject.play()'''
        def setTickInterval(self, newTickInterval):
            '''void Phonon.MediaObject.setTickInterval(int newTickInterval)'''
        def setTransitionTime(self, msec):
            '''void Phonon.MediaObject.setTransitionTime(int msec)'''
        def transitionTime(self):
            '''int Phonon.MediaObject.transitionTime()'''
            return int()
        def setPrefinishMark(self, msecToEnd):
            '''void Phonon.MediaObject.setPrefinishMark(int msecToEnd)'''
        def prefinishMark(self):
            '''int Phonon.MediaObject.prefinishMark()'''
            return int()
        def remainingTime(self):
            '''int Phonon.MediaObject.remainingTime()'''
            return int()
        def totalTime(self):
            '''int Phonon.MediaObject.totalTime()'''
            return int()
        def currentTime(self):
            '''int Phonon.MediaObject.currentTime()'''
            return int()
        def clearQueue(self):
            '''void Phonon.MediaObject.clearQueue()'''
        def enqueue(self, source):
            '''void Phonon.MediaObject.enqueue(Phonon.MediaSource source)'''
        def enqueue(self, sources):
            '''void Phonon.MediaObject.enqueue(list-of-Phonon.MediaSource sources)'''
        def enqueue(self, urls):
            '''void Phonon.MediaObject.enqueue(list-of-QUrl urls)'''
        def setQueue(self, sources):
            '''void Phonon.MediaObject.setQueue(list-of-Phonon.MediaSource sources)'''
        def setQueue(self, urls):
            '''void Phonon.MediaObject.setQueue(list-of-QUrl urls)'''
        def queue(self):
            '''list-of-Phonon.MediaSource Phonon.MediaObject.queue()'''
            return [Phonon.MediaSource()]
        def setCurrentSource(self, source):
            '''void Phonon.MediaObject.setCurrentSource(Phonon.MediaSource source)'''
        def currentSource(self):
            '''Phonon.MediaSource Phonon.MediaObject.currentSource()'''
            return Phonon.MediaSource()
        def errorType(self):
            '''Phonon.ErrorType Phonon.MediaObject.errorType()'''
            return Phonon.ErrorType()
        def errorString(self):
            '''QString Phonon.MediaObject.errorString()'''
            return QString()
        def metaData(self, key):
            '''QStringList Phonon.MediaObject.metaData(QString key)'''
            return QStringList()
        def metaData(self, key):
            '''QStringList Phonon.MediaObject.metaData(Phonon.MetaData key)'''
            return QStringList()
        def metaData(self):
            '''dict-of-QString-list-of-QString Phonon.MediaObject.metaData()'''
            return dict-of-QString-list-of-QString()
        def tickInterval(self):
            '''int Phonon.MediaObject.tickInterval()'''
            return int()
        def isSeekable(self):
            '''bool Phonon.MediaObject.isSeekable()'''
            return bool()
        def hasVideo(self):
            '''bool Phonon.MediaObject.hasVideo()'''
            return bool()
        def state(self):
            '''Phonon.State Phonon.MediaObject.state()'''
            return Phonon.State()


